@@ -44,7 +44,7 @@ def barplot_neighbors(Nrange=2 ** np.arange(1, 11),
                             for alg in algorithms])
 
     for i, NN in enumerate(Nrange):
-        print "N = %i (%i out of %i)" % (NN, i + 1, len(Nrange))
+        print("N = %i (%i out of %i)" % (NN, i + 1, len(Nrange)))
         X = get_data(NN, D, dataset)
         for algorithm in algorithms:
             nbrs = neighbors.NearestNeighbors(n_neighbors=min(NN, k),
@@ -67,7 +67,7 @@ def barplot_neighbors(Nrange=2 ** np.arange(1, 11),
                             for alg in algorithms])
 
     for i, DD in enumerate(Drange):
-        print "D = %i (%i out of %i)" % (DD, i + 1, len(Drange))
+        print("D = %i (%i out of %i)" % (DD, i + 1, len(Drange)))
         X = get_data(N, DD, dataset)
         for algorithm in algorithms:
             nbrs = neighbors.NearestNeighbors(n_neighbors=k,
@@ -92,7 +92,7 @@ def barplot_neighbors(Nrange=2 ** np.arange(1, 11),
     X = get_data(N, DD, dataset)
 
     for i, kk in enumerate(krange):
-        print "k = %i (%i out of %i)" % (kk, i + 1, len(krange))
+        print("k = %i (%i out of %i)" % (kk, i + 1, len(krange)))
         for algorithm in algorithms:
             nbrs = neighbors.NearestNeighbors(n_neighbors=kk,
                                               algorithm=algorithm,
@@ -131,10 +131,10 @@ def barplot_neighbors(Nrange=2 ** np.arange(1, 11),
             xvals = 0.1 + i * (1 + len(vals)) + np.arange(len(vals))
             width = 0.8
 
-            pl.bar(xvals, build_time[alg] - bottom,
-                   width, bottom, color='r')
-            pl.bar(xvals, query_time[alg],
-                   width, build_time[alg], color='b')
+            c_bar = pl.bar(xvals, build_time[alg] - bottom,
+                           width, bottom, color='r')
+            q_bar = pl.bar(xvals, query_time[alg],
+                           width, build_time[alg], color='b')
 
             tick_vals += list(xvals + 0.5 * width)
             tick_labels += ['%i' % val for val in vals]
@@ -145,7 +145,7 @@ def barplot_neighbors(Nrange=2 ** np.arange(1, 11),
                     va='top',
                     bbox=dict(facecolor='w', edgecolor='w', alpha=0.5))
 
-            pl.ylabel('time (seconds)')
+            pl.ylabel('Time (s)')
 
         ax.xaxis.set_major_locator(ticker.FixedLocator(tick_vals))
         ax.xaxis.set_major_formatter(ticker.FixedFormatter(tick_labels))
@@ -174,10 +174,10 @@ def barplot_neighbors(Nrange=2 ** np.arange(1, 11),
                 transform=ax.transAxes, rotation=-90,
                 ha='right', va='center')
 
-        pl.gcf().suptitle("%s data\nred = construction;  blue = N-point query"
-                          % (dataset[0].upper() + dataset[1:]),
-                          fontsize=16)
+        pl.gcf().suptitle("%s data set" % dataset.capitalize(), fontsize=16)
 
+    pl.figlegend((c_bar, q_bar), ('construction', 'N-point query'),
+                 'upper right')
 
 if __name__ == '__main__':
     barplot_neighbors(dataset='digits')
