@@ -16,7 +16,7 @@ from sklearn.datasets.samples_generator import make_low_rank_matrix
 from sklearn.externals.six.moves import xrange
 
 
-def alt_nnmf(V, r, max_iter=1000, tol=1e-3, R=None):
+def alt_nnmf(V, r, max_iter=1000, tol=1e-3, init='random'):
     '''
     A, S = nnmf(X, r, tol=1e-3, R=None)
 
@@ -33,8 +33,8 @@ def alt_nnmf(V, r, max_iter=1000, tol=1e-3, R=None):
     tol : double
         tolerance threshold for early exit (when the update factor is within
         tol of 1., the function exits)
-    R : integer, optional
-        random seed
+    init : string
+        Method used to initialize the procedure.
 
     Returns
     -------
@@ -52,12 +52,7 @@ def alt_nnmf(V, r, max_iter=1000, tol=1e-3, R=None):
     # Nomenclature in the function follows Lee & Seung
     eps = 1e-5
     n, m = V.shape
-    if R == "svd":
-        W, H = _initialize_nmf(V, r)
-    elif R is None:
-        R = np.random.mtrand._rand
-        W = np.abs(R.standard_normal((n, r)))
-        H = np.abs(R.standard_normal((r, m)))
+    W, H = _initialize_nmf(V, r, init, random_state=0)
 
     for i in xrange(max_iter):
         updateH = np.dot(W.T, V) / (np.dot(np.dot(W.T, W), H) + eps)
@@ -78,17 +73,15 @@ def report(error, time):
 
 
 def benchmark(samples_range, features_range, rank=50, tolerance=1e-5):
-    it = 0
     timeset = defaultdict(lambda: [])
     err = defaultdict(lambda: [])
 
-    max_it = len(samples_range) * len(features_range)
     for n_samples in samples_range:
         for n_features in features_range:
             print("%2d samples, %2d features" % (n_samples, n_features))
             print('=======================')
             X = np.abs(make_low_rank_matrix(n_samples, n_features,
-                       effective_rank=rank,  tail_strength=0.2))
+                       effective_rank=rank, tail_strength=0.2))
 
             gc.collect()
             print("benchmarking nndsvd-nmf: ")
@@ -122,7 +115,7 @@ def benchmark(samples_range, features_range, rank=50, tolerance=1e-5):
             gc.collect()
             print("benchmarking random-nmf")
             tstart = time()
-            m = NMF(n_components=30, init=None, max_iter=1000,
+            m = NMF(n_components=30, init='random', max_iter=1000,
                     tol=tolerance).fit(X)
             tend = time() - tstart
             timeset['random-nmf'].append(tend)
@@ -132,7 +125,7 @@ def benchmark(samples_range, features_range, rank=50, tolerance=1e-5):
             gc.collect()
             print("benchmarking alt-random-nmf")
             tstart = time()
-            W, H = alt_nnmf(X, r=30, R=None, tol=tolerance)
+            W, H = alt_nnmf(X, r=30, init='random', tol=tolerance)
             tend = time() - tstart
             timeset['alt-random-nmf'].append(tend)
             err['alt-random-nmf'].append(np.linalg.norm(X - np.dot(W, H)))
@@ -151,7 +144,8 @@ if __name__ == '__main__':
     timeset, err = benchmark(samples_range, features_range)
 
     for i, results in enumerate((timeset, err)):
-        fig = plt.figure('scikit-learn Non-Negative Matrix Factorization benchmark results')
+        fig = plt.figure('scikit-learn Non-Negative Matrix Factorization'
+                         'benchmark results')
         ax = fig.gca(projection='3d')
         for c, (label, timings) in zip('rbgcm', sorted(results.iteritems())):
             X, Y = np.meshgrid(samples_range, features_range)
