@@ -8,9 +8,9 @@ import numpy as np
 from scipy.cluster import hierarchy
 import pylab as pl
 
-from sklearn.cluster import Ward
+from sklearn.cluster import AgglomerativeClustering
 
-ward = Ward(n_clusters=3)
+ward = AgglomerativeClustering(n_clusters=3, linkage='ward')
 
 n_samples = np.logspace(.5, 3, 9)
 n_features = np.logspace(1, 3.5, 7)
