@@ -42,7 +42,7 @@ def atomic_benchmark_estimator(estimator, X_test, verbose=False):
     n_instances = X_test.shape[0]
     runtimes = np.zeros(n_instances, dtype=np.float)
     for i in range(n_instances):
-        instance = X_test[i, :]
+        instance = X_test[[i], :]
         start = time.time()
         estimator.predict(instance)
         runtimes[i] = time.time() - start
@@ -241,7 +241,7 @@ def benchmark_throughputs(configuration, duration_secs=0.1):
         start_time = time.time()
         n_predictions = 0
         while (time.time() - start_time) < duration_secs:
-            estimator_config['instance'].predict(X_test[0])
+            estimator_config['instance'].predict(X_test[[0]])
             n_predictions += 1
         throughputs[estimator_config['name']] = n_predictions / duration_secs
     return throughputs
