@@ -19,12 +19,12 @@ and finally the ground truth.
 print(__doc__)
 
 
-# Code source: Gael Varoqueux
-# Modified for Documentation merge by Jaques Grobler
+# Code source: Gaël Varoquaux
+# Modified for documentation by Jaques Grobler
 # License: BSD 3 clause
 
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
 
 
@@ -45,12 +45,12 @@ estimators = {'k_means_iris_3': KMeans(n_clusters=3),
 
 
 fignum = 1
-for name, est in estimators.iteritems():
-    fig = pl.figure(fignum, figsize=(4, 3))
-    pl.clf()
+for name, est in estimators.items():
+    fig = plt.figure(fignum, figsize=(4, 3))
+    plt.clf()
     ax = Axes3D(fig, rect=[0, 0, .95, 1], elev=48, azim=134)
 
-    pl.cla()
+    plt.cla()
     est.fit(X)
     labels = est.labels_
 
@@ -65,11 +65,11 @@ for name, est in estimators.iteritems():
     fignum = fignum + 1
 
 # Plot the ground truth
-fig = pl.figure(fignum, figsize=(4, 3))
-pl.clf()
+fig = plt.figure(fignum, figsize=(4, 3))
+plt.clf()
 ax = Axes3D(fig, rect=[0, 0, .95, 1], elev=48, azim=134)
 
-pl.cla()
+plt.cla()
 
 for name, label in [('Setosa', 0),
                     ('Versicolour', 1),
@@ -89,4 +89,4 @@ ax.w_zaxis.set_ticklabels([])
 ax.set_xlabel('Petal width')
 ax.set_ylabel('Sepal length')
 ax.set_zlabel('Petal length')
-pl.show()
+plt.show()
