@@ -10,10 +10,10 @@ criterion), yielding the Ledoit-Wolf covariance estimate.
 
 Chen et al. proposed an improvement of the Ledoit-Wolf shrinkage
 parameter, the OAS coefficient, whose convergence is significantly
-better under the assumption that the data are gaussian.
+better under the assumption that the data are Gaussian.
 
 This example, inspired from Chen's publication [1], shows a comparison
-of the estimated MSE of the LW and OAS methods, using gaussian
+of the estimated MSE of the LW and OAS methods, using Gaussian
 distributed data.
 
 [1] "Shrinkage Algorithms for MMSE Covariance Estimation"
@@ -23,7 +23,7 @@ Chen et al., IEEE Trans. on Sign. Proc., Volume 58, Issue 10, October 2010.
 print(__doc__)
 
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
 from scipy.linalg import toeplitz, cholesky
 
 from sklearn.covariance import LedoitWolf, OAS
@@ -58,26 +58,26 @@ for i, n_samples in enumerate(n_samples_range):
         oa_shrinkage[i, j] = oa.shrinkage_
 
 # plot MSE
-pl.subplot(2, 1, 1)
-pl.errorbar(n_samples_range, lw_mse.mean(1), yerr=lw_mse.std(1),
-            label='Ledoit-Wolf', color='g')
-pl.errorbar(n_samples_range, oa_mse.mean(1), yerr=oa_mse.std(1),
-            label='OAS', color='r')
-pl.ylabel("Squared error")
-pl.legend(loc="upper right")
-pl.title("Comparison of covariance estimators")
-pl.xlim(5, 31)
+plt.subplot(2, 1, 1)
+plt.errorbar(n_samples_range, lw_mse.mean(1), yerr=lw_mse.std(1),
+             label='Ledoit-Wolf', color='g')
+plt.errorbar(n_samples_range, oa_mse.mean(1), yerr=oa_mse.std(1),
+             label='OAS', color='r')
+plt.ylabel("Squared error")
+plt.legend(loc="upper right")
+plt.title("Comparison of covariance estimators")
+plt.xlim(5, 31)
 
 # plot shrinkage coefficient
-pl.subplot(2, 1, 2)
-pl.errorbar(n_samples_range, lw_shrinkage.mean(1), yerr=lw_shrinkage.std(1),
-            label='Ledoit-Wolf', color='g')
-pl.errorbar(n_samples_range, oa_shrinkage.mean(1), yerr=oa_shrinkage.std(1),
-            label='OAS', color='r')
-pl.xlabel("n_samples")
-pl.ylabel("Shrinkage")
-pl.legend(loc="lower right")
-pl.ylim(pl.ylim()[0], 1. + (pl.ylim()[1] - pl.ylim()[0]) / 10.)
-pl.xlim(5, 31)
+plt.subplot(2, 1, 2)
+plt.errorbar(n_samples_range, lw_shrinkage.mean(1), yerr=lw_shrinkage.std(1),
+             label='Ledoit-Wolf', color='g')
+plt.errorbar(n_samples_range, oa_shrinkage.mean(1), yerr=oa_shrinkage.std(1),
+             label='OAS', color='r')
+plt.xlabel("n_samples")
+plt.ylabel("Shrinkage")
+plt.legend(loc="lower right")
+plt.ylim(plt.ylim()[0], 1. + (plt.ylim()[1] - plt.ylim()[0]) / 10.)
+plt.xlim(5, 31)
 
-pl.show()
+plt.show()
