@@ -19,11 +19,11 @@ information on this dataset.
 print(__doc__)
 
 
-# Code source: Gael Varoqueux
-# Modified for Documentation merge by Jaques Grobler
+# Code source: Gaël Varoquaux
+# Modified for documentation by Jaques Grobler
 # License: BSD 3 clause
 
-import pylab as pl
+import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
 from sklearn import datasets
 from sklearn.decomposition import PCA
@@ -36,26 +36,26 @@ Y = iris.target
 x_min, x_max = X[:, 0].min() - .5, X[:, 0].max() + .5
 y_min, y_max = X[:, 1].min() - .5, X[:, 1].max() + .5
 
-pl.figure(2, figsize=(8, 6))
-pl.clf()
+plt.figure(2, figsize=(8, 6))
+plt.clf()
 
 # Plot the training points
-pl.scatter(X[:, 0], X[:, 1], c=Y, cmap=pl.cm.Paired)
-pl.xlabel('Sepal length')
-pl.ylabel('Sepal width')
+plt.scatter(X[:, 0], X[:, 1], c=Y, cmap=plt.cm.Paired)
+plt.xlabel('Sepal length')
+plt.ylabel('Sepal width')
 
-pl.xlim(x_min, x_max)
-pl.ylim(y_min, y_max)
-pl.xticks(())
-pl.yticks(())
+plt.xlim(x_min, x_max)
+plt.ylim(y_min, y_max)
+plt.xticks(())
+plt.yticks(())
 
 # To getter a better understanding of interaction of the dimensions
 # plot the first three PCA dimensions
-fig = pl.figure(1, figsize=(8, 6))
+fig = plt.figure(1, figsize=(8, 6))
 ax = Axes3D(fig, elev=-150, azim=110)
 X_reduced = PCA(n_components=3).fit_transform(iris.data)
 ax.scatter(X_reduced[:, 0], X_reduced[:, 1], X_reduced[:, 2], c=Y,
-           cmap=pl.cm.Paired)
+           cmap=plt.cm.Paired)
 ax.set_title("First three PCA directions")
 ax.set_xlabel("1st eigenvector")
 ax.w_xaxis.set_ticklabels([])
@@ -64,4 +64,4 @@ ax.w_yaxis.set_ticklabels([])
 ax.set_zlabel("3rd eigenvector")
 ax.w_zaxis.set_ticklabels([])
 
-pl.show()
+plt.show()
