@@ -18,7 +18,7 @@ import logging
 from time import time
 
 from numpy.random import RandomState
-import pylab as pl
+import matplotlib.pyplot as plt
 
 from sklearn.datasets import fetch_olivetti_faces
 from sklearn.cluster import MiniBatchKMeans
@@ -50,17 +50,17 @@ print("Dataset consists of %d faces" % n_samples)
 
 ###############################################################################
 def plot_gallery(title, images, n_col=n_col, n_row=n_row):
-    pl.figure(figsize=(2. * n_col, 2.26 * n_row))
-    pl.suptitle(title, size=16)
+    plt.figure(figsize=(2. * n_col, 2.26 * n_row))
+    plt.suptitle(title, size=16)
     for i, comp in enumerate(images):
-        pl.subplot(n_row, n_col, i + 1)
+        plt.subplot(n_row, n_col, i + 1)
         vmax = max(comp.max(), -comp.min())
-        pl.imshow(comp.reshape(image_shape), cmap=pl.cm.gray,
-                  interpolation='nearest',
-                  vmin=-vmax, vmax=vmax)
-        pl.xticks(())
-        pl.yticks(())
-    pl.subplots_adjust(0.01, 0.05, 0.99, 0.93, 0.04, 0.)
+        plt.imshow(comp.reshape(image_shape), cmap=plt.cm.gray,
+                   interpolation='nearest',
+                   vmin=-vmax, vmax=vmax)
+        plt.xticks(())
+        plt.yticks(())
+    plt.subplots_adjust(0.01, 0.05, 0.99, 0.93, 0.04, 0.)
 
 ###############################################################################
 # List of the different estimators, whether to center and transpose the
@@ -71,8 +71,7 @@ estimators = [
      True),
 
     ('Non-negative components - NMF',
-     decomposition.NMF(n_components=n_components, init='nndsvda', beta=5.0,
-                       tol=5e-3, sparseness='components'),
+     decomposition.NMF(n_components=n_components, init='nndsvda', tol=5e-3),
      False),
 
     ('Independent components - FastICA',
@@ -130,4 +129,4 @@ for name, estimator, center in estimators:
     plot_gallery('%s - Train time %.1fs' % (name, train_time),
                  components_[:n_components])
 
-pl.show()
+plt.show()
