@@ -62,7 +62,7 @@ def plot_figs(fig_num, elev, azim):
     plt.clf()
     ax = Axes3D(fig, rect=[0, 0, .95, 1], elev=elev, azim=azim)
 
-    ax.scatter(a[::10], b[::10], c[::10], c=density, marker='+', alpha=.4)
+    ax.scatter(a[::10], b[::10], c[::10], c=density[::10], marker='+', alpha=.4)
     Y = np.c_[a, b, c]
 
     # Using SciPy's SVD, this would be:
