@@ -6,15 +6,15 @@
 Gaussian Processes regression: goodness-of-fit on the 'diabetes' dataset
 ========================================================================
 
-This example consists in fitting a Gaussian Process model onto the diabetes
+In this example, we fit a Gaussian Process model onto the diabetes
 dataset.
 
-The correlation parameters are determined by means of maximum likelihood
-estimation (MLE). An anisotropic squared exponential correlation model with a
-constant regression model are assumed. We also used a nugget = 1e-2 in order to
-account for the (strong) noise in the targets.
+We determine the correlation parameters with maximum likelihood
+estimation (MLE). We use an anisotropic squared exponential
+correlation model with a constant regression model. We also use a
+nugget of 1e-2 to account for the (strong) noise in the targets.
 
-We compute then compute a cross-validation estimate of the coefficient of
+We compute a cross-validation estimate of the coefficient of
 determination (R2) without reperforming MLE, using the set of correlation
 parameters found on the whole dataset.
 """
