@@ -19,7 +19,7 @@ marginal log-likelihood of the observations.
 print(__doc__)
 
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
 from scipy import stats
 
 from sklearn.linear_model import BayesianRidge, LinearRegression
@@ -28,7 +28,7 @@ from sklearn.linear_model import BayesianRidge, LinearRegression
 # Generating simulated data with Gaussian weigthts
 np.random.seed(0)
 n_samples, n_features = 100, 100
-X = np.random.randn(n_samples, n_features)  # Create gaussian data
+X = np.random.randn(n_samples, n_features)  # Create Gaussian data
 # Create weigts with a precision lambda_ of 4.
 lambda_ = 4.
 w = np.zeros(n_features)
@@ -52,27 +52,27 @@ ols.fit(X, y)
 
 ###############################################################################
 # Plot true weights, estimated weights and histogram of the weights
-pl.figure(figsize=(6, 5))
-pl.title("Weights of the model")
-pl.plot(clf.coef_, 'b-', label="Bayesian Ridge estimate")
-pl.plot(w, 'g-', label="Ground truth")
-pl.plot(ols.coef_, 'r--', label="OLS estimate")
-pl.xlabel("Features")
-pl.ylabel("Values of the weights")
-pl.legend(loc="best", prop=dict(size=12))
+plt.figure(figsize=(6, 5))
+plt.title("Weights of the model")
+plt.plot(clf.coef_, 'b-', label="Bayesian Ridge estimate")
+plt.plot(w, 'g-', label="Ground truth")
+plt.plot(ols.coef_, 'r--', label="OLS estimate")
+plt.xlabel("Features")
+plt.ylabel("Values of the weights")
+plt.legend(loc="best", prop=dict(size=12))
 
-pl.figure(figsize=(6, 5))
-pl.title("Histogram of the weights")
-pl.hist(clf.coef_, bins=n_features, log=True)
-pl.plot(clf.coef_[relevant_features], 5 * np.ones(len(relevant_features)),
-        'ro', label="Relevant features")
-pl.ylabel("Features")
-pl.xlabel("Values of the weights")
-pl.legend(loc="lower left")
+plt.figure(figsize=(6, 5))
+plt.title("Histogram of the weights")
+plt.hist(clf.coef_, bins=n_features, log=True)
+plt.plot(clf.coef_[relevant_features], 5 * np.ones(len(relevant_features)),
+         'ro', label="Relevant features")
+plt.ylabel("Features")
+plt.xlabel("Values of the weights")
+plt.legend(loc="lower left")
 
-pl.figure(figsize=(6, 5))
-pl.title("Marginal log-likelihood")
-pl.plot(clf.scores_)
-pl.ylabel("Score")
-pl.xlabel("Iterations")
-pl.show()
+plt.figure(figsize=(6, 5))
+plt.title("Marginal log-likelihood")
+plt.plot(clf.scores_)
+plt.ylabel("Score")
+plt.xlabel("Iterations")
+plt.show()
