@@ -37,7 +37,7 @@ y = (y > 4).astype(np.int)
 
 
 # Set regularization parameter
-for i, C in enumerate(10. ** np.arange(1, 4)):
+for i, C in enumerate((100, 1, 0.01)):
     # turn down tolerance for short training time
     clf_l1_LR = LogisticRegression(C=C, penalty='l1', tol=0.01)
     clf_l2_LR = LogisticRegression(C=C, penalty='l2', tol=0.01)
@@ -53,7 +53,7 @@ for i, C in enumerate(10. ** np.arange(1, 4)):
     sparsity_l1_LR = np.mean(coef_l1_LR == 0) * 100
     sparsity_l2_LR = np.mean(coef_l2_LR == 0) * 100
 
-    print("C=%d" % C)
+    print("C=%.2f" % C)
     print("Sparsity with L1 penalty: %.2f%%" % sparsity_l1_LR)
     print("score with L1 penalty: %.4f" % clf_l1_LR.score(X, y))
     print("Sparsity with L2 penalty: %.2f%%" % sparsity_l2_LR)
@@ -69,7 +69,7 @@ for i, C in enumerate(10. ** np.arange(1, 4)):
                    cmap='binary', vmax=1, vmin=0)
     l2_plot.imshow(np.abs(coef_l2_LR.reshape(8, 8)), interpolation='nearest',
                    cmap='binary', vmax=1, vmin=0)
-    plt.text(-8, 3, "C = %d" % C)
+    plt.text(-8, 3, "C = %.2f" % C)
 
     l1_plot.set_xticks(())
     l1_plot.set_yticks(())
