@@ -23,7 +23,7 @@ print(__doc__)
 # License: BSD 3 clause
 
 
-import pylab as pl
+import matplotlib.pyplot as plt
 import numpy as np
 from sklearn import datasets, linear_model
 
@@ -32,12 +32,11 @@ diabetes = datasets.load_diabetes()
 
 
 # Use only one feature
-diabetes_X = diabetes.data[:, np.newaxis]
-diabetes_X_temp = diabetes_X[:, :, 2]
+diabetes_X = diabetes.data[:, np.newaxis, 2]
 
 # Split the data into training/testing sets
-diabetes_X_train = diabetes_X_temp[:-20]
-diabetes_X_test = diabetes_X_temp[-20:]
+diabetes_X_train = diabetes_X[:-20]
+diabetes_X_test = diabetes_X[-20:]
 
 # Split the targets into training/testing sets
 diabetes_y_train = diabetes.target[:-20]
@@ -58,11 +57,11 @@ print("Residual sum of squares: %.2f"
 print('Variance score: %.2f' % regr.score(diabetes_X_test, diabetes_y_test))
 
 # Plot outputs
-pl.scatter(diabetes_X_test, diabetes_y_test,  color='black')
-pl.plot(diabetes_X_test, regr.predict(diabetes_X_test), color='blue',
-        linewidth=3)
+plt.scatter(diabetes_X_test, diabetes_y_test,  color='black')
+plt.plot(diabetes_X_test, regr.predict(diabetes_X_test), color='blue',
+         linewidth=3)
 
-pl.xticks(())
-pl.yticks(())
+plt.xticks(())
+plt.yticks(())
 
-pl.show()
+plt.show()
