@@ -13,7 +13,7 @@ from __future__ import division
 print(__doc__)
 
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
 
 
 def l1(xs):
@@ -35,8 +35,8 @@ def el(xs, z):
 
 
 def cross(ext):
-    pl.plot([-ext, ext], [0, 0], "k-")
-    pl.plot([0, 0], [-ext, ext], "k-")
+    plt.plot([-ext, ext], [0, 0], "k-")
+    plt.plot([0, 0], [-ext, ext], "k-")
 
 xs = np.linspace(0, 1, 100)
 
@@ -44,24 +44,24 @@ alpha = 0.501  # 0.5 division throuh zero
 
 cross(1.2)
 
-pl.plot(xs, l1(xs), "r-", label="L1")
-pl.plot(xs, -1.0 * l1(xs), "r-")
-pl.plot(-1 * xs, l1(xs), "r-")
-pl.plot(-1 * xs, -1.0 * l1(xs), "r-")
+plt.plot(xs, l1(xs), "r-", label="L1")
+plt.plot(xs, -1.0 * l1(xs), "r-")
+plt.plot(-1 * xs, l1(xs), "r-")
+plt.plot(-1 * xs, -1.0 * l1(xs), "r-")
 
-pl.plot(xs, l2(xs), "b-", label="L2")
-pl.plot(xs, -1.0 * l2(xs), "b-")
-pl.plot(-1 * xs, l2(xs), "b-")
-pl.plot(-1 * xs, -1.0 * l2(xs), "b-")
+plt.plot(xs, l2(xs), "b-", label="L2")
+plt.plot(xs, -1.0 * l2(xs), "b-")
+plt.plot(-1 * xs, l2(xs), "b-")
+plt.plot(-1 * xs, -1.0 * l2(xs), "b-")
 
-pl.plot(xs, el(xs, alpha), "y-", label="Elastic Net")
-pl.plot(xs, -1.0 * el(xs, alpha), "y-")
-pl.plot(-1 * xs, el(xs, alpha), "y-")
-pl.plot(-1 * xs, -1.0 * el(xs, alpha), "y-")
+plt.plot(xs, el(xs, alpha), "y-", label="Elastic Net")
+plt.plot(xs, -1.0 * el(xs, alpha), "y-")
+plt.plot(-1 * xs, el(xs, alpha), "y-")
+plt.plot(-1 * xs, -1.0 * el(xs, alpha), "y-")
 
-pl.xlabel(r"$w_0$")
-pl.ylabel(r"$w_1$")
-pl.legend()
+plt.xlabel(r"$w_0$")
+plt.ylabel(r"$w_1$")
+plt.legend()
 
-pl.axis("equal")
-pl.show()
+plt.axis("equal")
+plt.show()
