@@ -9,7 +9,7 @@ is proportional to its weight.
 print(__doc__)
 
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
 from sklearn import linear_model
 
 # we create 20 points
@@ -22,27 +22,27 @@ sample_weight[:10] *= 10
 
 # plot the weighted data points
 xx, yy = np.meshgrid(np.linspace(-4, 5, 500), np.linspace(-4, 5, 500))
-pl.figure()
-pl.scatter(X[:, 0], X[:, 1], c=y, s=sample_weight, alpha=0.9,
-           cmap=pl.cm.bone)
+plt.figure()
+plt.scatter(X[:, 0], X[:, 1], c=y, s=sample_weight, alpha=0.9,
+            cmap=plt.cm.bone)
 
 ## fit the unweighted model
 clf = linear_model.SGDClassifier(alpha=0.01, n_iter=100)
 clf.fit(X, y)
 Z = clf.decision_function(np.c_[xx.ravel(), yy.ravel()])
 Z = Z.reshape(xx.shape)
-no_weights = pl.contour(xx, yy, Z, levels=[0], linestyles=['solid'])
+no_weights = plt.contour(xx, yy, Z, levels=[0], linestyles=['solid'])
 
 ## fit the weighted model
 clf = linear_model.SGDClassifier(alpha=0.01, n_iter=100)
 clf.fit(X, y, sample_weight=sample_weight)
 Z = clf.decision_function(np.c_[xx.ravel(), yy.ravel()])
 Z = Z.reshape(xx.shape)
-samples_weights = pl.contour(xx, yy, Z, levels=[0], linestyles=['dashed'])
+samples_weights = plt.contour(xx, yy, Z, levels=[0], linestyles=['dashed'])
 
-pl.legend([no_weights.collections[0], samples_weights.collections[0]],
-          ["no weights", "with weights"], loc="lower left")
+plt.legend([no_weights.collections[0], samples_weights.collections[0]],
+           ["no weights", "with weights"], loc="lower left")
 
-pl.xticks(())
-pl.yticks(())
-pl.show()
+plt.xticks(())
+plt.yticks(())
+plt.show()
