@@ -19,7 +19,7 @@ print(__doc__)
 ###############################################################################
 # Generate sample data
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
 from sklearn import neighbors
 
 np.random.seed(0)
@@ -38,12 +38,12 @@ for i, weights in enumerate(['uniform', 'distance']):
     knn = neighbors.KNeighborsRegressor(n_neighbors, weights=weights)
     y_ = knn.fit(X, y).predict(T)
 
-    pl.subplot(2, 1, i + 1)
-    pl.scatter(X, y, c='k', label='data')
-    pl.plot(T, y_, c='g', label='prediction')
-    pl.axis('tight')
-    pl.legend()
-    pl.title("KNeighborsRegressor (k = %i, weights = '%s')" % (n_neighbors,
-                                                               weights))
+    plt.subplot(2, 1, i + 1)
+    plt.scatter(X, y, c='k', label='data')
+    plt.plot(T, y_, c='g', label='prediction')
+    plt.axis('tight')
+    plt.legend()
+    plt.title("KNeighborsRegressor (k = %i, weights = '%s')" % (n_neighbors,
+                                                                weights))
 
-pl.show()
+plt.show()
