@@ -20,9 +20,9 @@ y = boston.target
 # is a prediction obtained by cross validated:
 predicted = cross_val_predict(lr, boston.data, y, cv=10)
 
-fig,ax = plt.subplots()
+fig, ax = plt.subplots()
 ax.scatter(y, predicted)
 ax.plot([y.min(), y.max()], [y.min(), y.max()], 'k--', lw=4)
 ax.set_xlabel('Measured')
 ax.set_ylabel('Predicted')
-fig.show()
+plt.show()
