@@ -1,4 +1,4 @@
-"""
+r"""
 =====================================================================
 The Johnson-Lindenstrauss bound for embedding with random projections
 =====================================================================
@@ -18,7 +18,8 @@ The distortion introduced by a random projection `p` is asserted by
 the fact that `p` is defining an eps-embedding with good probability
 as defined by:
 
-  (1 - eps) ||u - v||^2 < ||p(u) - p(v)||^2 < (1 + eps) ||u - v||^2
+.. math::
+   (1 - eps) \|u - v\|^2 < \|p(u) - p(v)\|^2 < (1 + eps) \|u - v\|^2
 
 Where u and v are any rows taken from a dataset of shape [n_samples,
 n_features] and p is a projection by a random Gaussian N(0, 1) matrix
@@ -27,7 +28,8 @@ with shape [n_components, n_features] (or a sparse Achlioptas matrix).
 The minimum number of components to guarantees the eps-embedding is
 given by:
 
-  n_components >= 4 log(n_samples) / (eps^2 / 2 - eps^3 / 3)
+.. math::
+   n\_components >= 4 log(n\_samples) / (eps^2 / 2 - eps^3 / 3)
 
 
 The first plot shows that with an increasing number of samples ``n_samples``,
