@@ -16,7 +16,7 @@ print(__doc__)
 # Licence: BSD
 
 import numpy as np
-import pylab as pl
+import matplotlib.pyplot as plt
 from sklearn import datasets
 from sklearn import svm
 from sklearn.semi_supervised import label_propagation
@@ -61,19 +61,19 @@ color_map = {-1: (1, 1, 1), 0: (0, 0, .9), 1: (1, 0, 0), 2: (.8, .6, 0)}
 for i, (clf, y_train) in enumerate((ls30, ls50, ls100, rbf_svc)):
     # Plot the decision boundary. For that, we will assign a color to each
     # point in the mesh [x_min, m_max]x[y_min, y_max].
-    pl.subplot(2, 2, i + 1)
+    plt.subplot(2, 2, i + 1)
     Z = clf.predict(np.c_[xx.ravel(), yy.ravel()])
 
     # Put the result into a color plot
     Z = Z.reshape(xx.shape)
-    pl.contourf(xx, yy, Z, cmap=pl.cm.Paired)
-    pl.axis('off')
+    plt.contourf(xx, yy, Z, cmap=plt.cm.Paired)
+    plt.axis('off')
 
     # Plot also the training points
     colors = [color_map[y] for y in y_train]
-    pl.scatter(X[:, 0], X[:, 1], c=colors, cmap=pl.cm.Paired)
+    plt.scatter(X[:, 0], X[:, 1], c=colors, cmap=plt.cm.Paired)
 
-    pl.title(titles[i])
+    plt.title(titles[i])
 
-pl.text(.90, 0, "Unlabeled points are colored white")
-pl.show()
+plt.text(.90, 0, "Unlabeled points are colored white")
+plt.show()
