@@ -20,16 +20,16 @@ X = iris.data[:, :2]  # we only take the first two features. We could
 Y = iris.target
 
 
-def my_kernel(x, y):
+def my_kernel(X, Y):
     """
     We create a custom kernel:
 
                  (2  0)
-    k(x, y) = x  (    ) y.T
+    k(X, Y) = X  (    ) Y.T
                  (0  1)
     """
     M = np.array([[2, 0], [0, 1.0]])
-    return np.dot(np.dot(x, M), y.T)
+    return np.dot(np.dot(X, M), Y.T)
 
 
 h = .02  # step size in the mesh
