@@ -4,7 +4,7 @@ RBF SVM parameters
 ==================
 
 This example illustrates the effect of the parameters ``gamma`` and ``C`` of
-the Radius Basis Function (RBF) kernel SVM.
+the Radial Basis Function (RBF) kernel SVM.
 
 Intuitively, the ``gamma`` parameter defines how far the influence of a single
 training example reaches, with low values meaning 'far' and high values meaning
@@ -14,10 +14,10 @@ influence of samples selected by the model as support vectors.
 The ``C`` parameter trades off misclassification of training examples against
 simplicity of the decision surface. A low ``C`` makes the decision surface
 smooth, while a high ``C`` aims at classifying all training examples correctly
-by give the model freedom to select more samples as support vectors.
+by giving the model freedom to select more samples as support vectors.
 
 The first plot is a visualization of the decision function for a variety of
-parameter values on simplified classification problem involving only 2 input
+parameter values on a simplified classification problem involving only 2 input
 features and 2 possible target classes (binary classification). Note that this
 kind of plot is not possible to do for problems with more features or target
 classes.
@@ -35,8 +35,8 @@ them appart in the blink of an eye.
 
 The behavior of the model is very sensitive to the ``gamma`` parameter. If
 ``gamma`` is too large, the radius of the area of influence of the support
-vectors only includes the support vector it-self and no amount of
-regularization with ``C`` will be able to prevent of overfitting.
+vectors only includes the support vector itself and no amount of
+regularization with ``C`` will be able to prevent overfitting.
 
 When ``gamma`` is very small, the model is too constrained and cannot capture
 the complexity or "shape" of the data. The region of influence of any selected
@@ -44,21 +44,21 @@ support vector would include the whole training set. The resulting model will
 behave similarly to a linear model with a set of hyperplanes that separate the
 centers of high density of any pair of two classes.
 
-For intermediate values, we can see on a the second plot that good models can
+For intermediate values, we can see on the second plot that good models can
 be found on a diagonal of ``C`` and ``gamma``. Smooth models (lower ``gamma``
 values) can be made more complex by selecting a larger number of support
 vectors (larger ``C`` values) hence the diagonal of good performing models.
 
 Finally one can also observe that for some intermediate values of ``gamma`` we
 get equally performing models when ``C`` becomes very large: it is not
-necessary to regularize by limiting the number support vectors. The radius of
+necessary to regularize by limiting the number of support vectors. The radius of
 the RBF kernel alone acts as a good structural regularizer. In practice though
 it might still be interesting to limit the number of support vectors with a
 lower value of ``C`` so as to favor models that use less memory and that are
 faster to predict.
 
 We should also note that small differences in scores results from the random
-splits of the cross-validation procedure. Those spurious variations can
+splits of the cross-validation procedure. Those spurious variations can be
 smoothed out by increasing the number of CV iterations ``n_iter`` at the
 expense of compute time. Increasing the value number of ``C_range`` and
 ``gamma_range`` steps will increase the resolution of the hyper-parameter heat
@@ -101,8 +101,8 @@ X = iris.data
 y = iris.target
 
 # Dataset for decision function visualization: we only keep the first two
-# features in X and sub-sample the dataset to keep only 2 class to has
-# to make it a binary classification problem.
+# features in X and sub-sample the dataset to keep only 2 classes and
+# make it a binary classification problem.
 
 X_2d = X[:, :2]
 X_2d = X_2d[y > 0]
