@@ -3,16 +3,17 @@
 Support Vector Regression (SVR) using linear and non-linear kernels
 ===================================================================
 
-Toy example of 1D regression using linear, polynominial and RBF
-kernels.
+Toy example of 1D regression using linear, polynomial and RBF kernels.
 
 """
 print(__doc__)
 
+import numpy as np
+from sklearn.svm import SVR
+import matplotlib.pyplot as plt
+
 ###############################################################################
 # Generate sample data
-import numpy as np
-
 X = np.sort(5 * np.random.rand(40, 1), axis=0)
 y = np.sin(X).ravel()
 
@@ -22,8 +23,6 @@ y[::5] += 3 * (0.5 - np.random.rand(8))
 
 ###############################################################################
 # Fit regression model
-from sklearn.svm import SVR
-
 svr_rbf = SVR(kernel='rbf', C=1e3, gamma=0.1)
 svr_lin = SVR(kernel='linear', C=1e3)
 svr_poly = SVR(kernel='poly', C=1e3, degree=2)
@@ -33,14 +32,13 @@ y_poly = svr_poly.fit(X, y).predict(X)
 
 ###############################################################################
 # look at the results
-import pylab as pl
-pl.scatter(X, y, c='k', label='data')
-pl.hold('on')
-pl.plot(X, y_rbf, c='g', label='RBF model')
-pl.plot(X, y_lin, c='r', label='Linear model')
-pl.plot(X, y_poly, c='b', label='Polynomial model')
-pl.xlabel('data')
-pl.ylabel('target')
-pl.title('Support Vector Regression')
-pl.legend()
-pl.show()
+plt.scatter(X, y, c='k', label='data')
+plt.hold('on')
+plt.plot(X, y_rbf, c='g', label='RBF model')
+plt.plot(X, y_lin, c='r', label='Linear model')
+plt.plot(X, y_poly, c='b', label='Polynomial model')
+plt.xlabel('data')
+plt.ylabel('target')
+plt.title('Support Vector Regression')
+plt.legend()
+plt.show()
