@@ -27,15 +27,15 @@ y = np.sin(X).ravel()
 y[::5] += 3 * (0.5 - rng.rand(16))
 
 # Fit regression model
-clf_1 = DecisionTreeRegressor(max_depth=2)
-clf_2 = DecisionTreeRegressor(max_depth=5)
-clf_1.fit(X, y)
-clf_2.fit(X, y)
+regr_1 = DecisionTreeRegressor(max_depth=2)
+regr_2 = DecisionTreeRegressor(max_depth=5)
+regr_1.fit(X, y)
+regr_2.fit(X, y)
 
 # Predict
 X_test = np.arange(0.0, 5.0, 0.01)[:, np.newaxis]
-y_1 = clf_1.predict(X_test)
-y_2 = clf_2.predict(X_test)
+y_1 = regr_1.predict(X_test)
+y_2 = regr_2.predict(X_test)
 
 # Plot the results
 plt.figure()
