@@ -44,7 +44,7 @@ def _fix_connectivity(X, connectivity, n_components=None,
     """
     n_samples = X.shape[0]
     if (connectivity.shape[0] != n_samples or
-        connectivity.shape[1] != n_samples):
+            connectivity.shape[1] != n_samples):
         raise ValueError('Wrong shape for connectivity matrix: %s '
                          'when X is %s' % (connectivity.shape, X.shape))
 
@@ -98,6 +98,8 @@ def ward_tree(X, connectivity=None, n_components=None, n_clusters=None,
     This is the structured version, that takes into account some topological
     structure between samples.
 
+    Read more in the :ref:`User Guide <hierarchical_clustering>`.
+
     Parameters
     ----------
     X : array, shape (n_samples, n_features)
@@ -311,6 +313,8 @@ def linkage_tree(X, connectivity=None, n_components=None,
     This is the structured version, that takes into account some topological
     structure between samples.
 
+    Read more in the :ref:`User Guide <hierarchical_clustering>`.
+
     Parameters
     ----------
     X : array, shape (n_samples, n_features)
@@ -387,8 +391,7 @@ def linkage_tree(X, connectivity=None, n_components=None,
     n_samples, n_features = X.shape
 
     linkage_choices = {'complete': _hierarchical.max_merge,
-                       'average': _hierarchical.average_merge,
-                      }
+                       'average': _hierarchical.average_merge}
     try:
         join_func = linkage_choices[linkage]
     except KeyError:
@@ -534,6 +537,7 @@ def linkage_tree(X, connectivity=None, n_components=None,
         return children, n_components, n_leaves, parent, distances
     return children, n_components, n_leaves, parent
 
+
 # Matching names to tree-building strategies
 def _complete_linkage(*args, **kwargs):
     kwargs['linkage'] = 'complete'
@@ -548,8 +552,7 @@ def _average_linkage(*args, **kwargs):
 _TREE_BUILDERS = dict(
     ward=ward_tree,
     complete=_complete_linkage,
-    average=_average_linkage,
-    )
+    average=_average_linkage)
 
 
 ###############################################################################
@@ -608,6 +611,8 @@ class AgglomerativeClustering(BaseEstimator, ClusterMixin):
     Recursively merges the pair of clusters that minimally increases
     a given linkage distance.
 
+    Read more in the :ref:`User Guide <hierarchical_clustering>`.
+
     Parameters
     ----------
     n_clusters : int, default=2
@@ -708,11 +713,15 @@ class AgglomerativeClustering(BaseEstimator, ClusterMixin):
         -------
         self
         """
-        X = check_array(X)
+        X = check_array(X, ensure_min_samples=2, estimator=self)
         memory = self.memory
         if isinstance(memory, six.string_types):
             memory = Memory(cachedir=memory, verbose=0)
 
+        if self.n_clusters <= 0:
+            raise ValueError("n_clusters should be an integer greater than 0."
+                             " %s was provided." % str(self.n_clusters))
+
         if self.linkage == "ward" and self.affinity != "euclidean":
             raise ValueError("%s was provided as affinity. Ward can only "
                              "work with euclidean distances." %
@@ -773,6 +782,8 @@ class FeatureAgglomeration(AgglomerativeClustering, AgglomerationTransform):
     Similar to AgglomerativeClustering, but recursively merges features
     instead of samples.
 
+    Read more in the :ref:`User Guide <hierarchical_clustering>`.
+
     Parameters
     ----------
     n_clusters : int, default 2
@@ -858,167 +869,10 @@ class FeatureAgglomeration(AgglomerativeClustering, AgglomerationTransform):
         -------
         self
         """
-        X = check_array(X, accept_sparse=['csr', 'csc', 'coo'])
-        if not (len(X.shape) == 2 and X.shape[0] > 0):
-            raise ValueError('At least one sample is required to fit the '
-                             'model. A data matrix of shape %s was given.'
-                             % (X.shape, ))
+        X = check_array(X, accept_sparse=['csr', 'csc', 'coo'],
+                        ensure_min_features=2, estimator=self)
         return AgglomerativeClustering.fit(self, X.T, **params)
 
     @property
     def fit_predict(self):
         raise AttributeError
-
-###############################################################################
-# Backward compatibility: class for Ward hierarchical clustering
-
-class Ward(AgglomerativeClustering):
-    """Ward hierarchical clustering: constructs a tree and cuts it.
-
-    Recursively merges the pair of clusters that minimally increases
-    within-cluster variance.
-
-    Parameters
-    ----------
-    n_clusters : int or ndarray
-        The number of clusters to find.
-
-    connectivity : sparse matrix (optional)
-        Connectivity matrix. Defines for each sample the neighboring
-        samples following a given structure of the data.
-        Default is None, i.e, the hierarchical clustering algorithm is
-        unstructured.
-
-    memory : Instance of joblib.Memory or string (optional)
-        Used to cache the output of the computation of the tree.
-        By default, no caching is done. If a string is given, it is the
-        path to the caching directory.
-
-    n_components : int (optional)
-        The number of connected components in the graph defined by the
-        connectivity matrix. If not set, it is estimated.
-
-    compute_full_tree : bool or 'auto' (optional)
-        Stop early the construction of the tree at n_clusters. This is
-        useful to decrease computation time if the number of clusters is
-        not small compared to the number of samples. This option is
-        useful only when specifying a connectivity matrix. Note also that
-        when varying the number of clusters and using caching, it may
-        be advantageous to compute the full tree.
-
-    Attributes
-    ----------
-    labels_ : array [n_features]
-        cluster labels for each feature
-
-    n_leaves_ : int
-        Number of leaves in the hierarchical tree.
-
-    n_components_ : int
-        The estimated number of connected components in the graph.
-
-    children_ : array-like, shape (n_nodes-1, 2)
-        The children of each non-leaf node. Values less than `n_samples`
-        refer to leaves of the tree. A greater value `i` indicates a node with
-        children `children_[i - n_samples]`.
-
-
-    See also
-    --------
-    AgglomerativeClustering : agglomerative hierarchical clustering
-    """
-    linkage = 'ward'
-
-    def __init__(self, n_clusters=2, memory=Memory(cachedir=None, verbose=0),
-                 connectivity=None, n_components=None,
-                 compute_full_tree='auto', pooling_func=np.mean):
-
-        warnings.warn("The Ward class is deprecated since 0.14 and will be "
-                      "removed in 0.17. Use the AgglomerativeClustering "
-                      "instead.", DeprecationWarning)
-        self.n_clusters = n_clusters
-        self.memory = memory
-        self.n_components = n_components
-        self.connectivity = connectivity
-        self.compute_full_tree = compute_full_tree
-        self.affinity = "euclidean"
-        self.pooling_func = pooling_func
-
-
-class WardAgglomeration(AgglomerationTransform, Ward):
-    """Feature agglomeration based on Ward hierarchical clustering
-
-    Parameters
-    ----------
-    n_clusters : int or ndarray
-        The number of clusters.
-
-    connectivity : array-like or callable, optional
-        Connectivity matrix. Defines for each sample the neighboring
-        samples following a given structure of the data.
-        This can be a connectivity matrix itself or a callable that transforms
-        the data into a connectivity matrix, such as derived from
-        kneighbors_graph. Default is None, i.e, the
-        hierarchical clustering algorithm is unstructured.
-
-    memory : Instance of joblib.Memory or string, optional
-        Used to cache the output of the computation of the tree.
-        By default, no caching is done. If a string is given, it is the
-        path to the caching directory.
-
-    n_components : int (optional)
-        The number of connected components in the graph defined by the
-        connectivity matrix. If not set, it is estimated.
-
-    compute_full_tree : bool or 'auto' (optional)
-        Stop early the construction of the tree at n_clusters. This is
-        useful to decrease computation time if the number of clusters is
-        not small compared to the number of samples. This option is
-        useful only when specifying a connectivity matrix. Note also that
-        when varying the number of cluster and using caching, it may
-        be advantageous to compute the full tree.
-
-    pooling_func : callable, default=np.mean
-        This combines the values of agglomerated features into a single
-        value, and should accept an array of shape [M, N] and the keyword
-        argument `axis=1`, and reduce it to an array of size [M].
-
-    Attributes
-    ----------
-    children_ : array-like, shape (n_nodes-1, 2)
-        The children of each non-leaf node. Values less than `n_features`
-        correspond to leaves of the tree which are the original samples.
-        A node `i` greater than or equal to `n_features` is a non-leaf
-        node and has children `children_[i - n_features]`. Alternatively
-        at the i-th iteration, children[i][0] and children[i][1]
-        are merged to form node `n_features + i`
-
-    labels_ : array [n_features]
-        cluster labels for each feature
-
-    n_leaves_ : int
-        Number of leaves in the hierarchical tree.
-
-    n_components_ : int
-        The estimated number of connected components in the graph.
-
-    """
-
-    def fit(self, X, y=None, **params):
-        """Fit the hierarchical clustering on the data
-
-        Parameters
-        ----------
-        X : array-like, shape = [n_samples, n_features]
-            The data
-
-        Returns
-        -------
-        self
-        """
-        X = check_array(X)
-        return Ward.fit(self, X.T, **params)
-
-    @property
-    def fit_predict(self):
-        raise AttributeError
