@@ -4,9 +4,6 @@ from sklearn.externals.six.moves import cPickle
 
 dumps, loads = cPickle.dumps, cPickle.loads
 
-import re
-import warnings
-
 import numpy as np
 from scipy import sparse
 
@@ -15,7 +12,7 @@ from sklearn.utils.testing import assert_equal
 from sklearn.utils.testing import assert_array_equal
 from sklearn.utils.testing import assert_raises
 from sklearn.utils.testing import assert_greater
-from sklearn.utils.testing import assert_true
+from sklearn.utils.testing import assert_warns_message
 
 from sklearn.cluster import SpectralClustering, spectral_clustering
 from sklearn.cluster.spectral import spectral_embedding
@@ -42,7 +39,7 @@ def test_spectral_clustering():
                                            affinity='precomputed',
                                            eigen_solver=eigen_solver,
                                            assign_labels=assign_labels
-                                           ).fit(mat)
+                                          ).fit(mat)
                 labels = model.labels_
                 if labels[0] == 0:
                     labels = 1 - labels
@@ -69,6 +66,7 @@ def test_spectral_amg_mode():
     S = sparse.coo_matrix(S)
     try:
         from pyamg import smoothed_aggregation_solver
+
         amg_loaded = True
     except ImportError:
         amg_loaded = False
@@ -135,16 +133,12 @@ def test_affinities():
     # on OSX and Linux
     X, y = make_blobs(n_samples=20, random_state=0,
                       centers=[[1, 1], [-1, -1]], cluster_std=0.01
-                      )
+                     )
     # nearest neighbors affinity
-    with warnings.catch_warnings(record=True) as warning_list:
-        warnings.simplefilter("always", UserWarning)
-        sp = SpectralClustering(n_clusters=2, affinity='nearest_neighbors',
-                                random_state=0)
-        labels = sp.fit(X).labels_
-        assert_equal(adjusted_rand_score(y, labels), 1)
-    assert_true(re.search(r'\bnot fully connected\b',
-                          str(warning_list[0].message)))
+    sp = SpectralClustering(n_clusters=2, affinity='nearest_neighbors',
+                            random_state=0)
+    assert_warns_message(UserWarning, 'not fully connected', sp.fit, X)
+    assert_equal(adjusted_rand_score(y, sp.labels_), 1)
 
     sp = SpectralClustering(n_clusters=2, gamma=2, random_state=0)
     labels = sp.fit(X).labels_
@@ -168,7 +162,7 @@ def test_affinities():
     assert_equal((X.shape[0],), labels.shape)
 
     def histogram(x, y, **kwargs):
-        """Histogram kernel implemented as a callable."""
+        # Histogram kernel implemented as a callable.
         assert_equal(kwargs, {})    # no kernel_params that we didn't ask for
         return np.minimum(x, y).sum()
 
@@ -191,8 +185,8 @@ def test_discretize(seed=8):
             y_true = np.array(y_true, np.float)
             # noise class assignment matrix
             y_indicator = sparse.coo_matrix((np.ones(n_samples),
-                                            (np.arange(n_samples),
-                                             y_true)),
+                                             (np.arange(n_samples),
+                                              y_true)),
                                             shape=(n_samples,
                                                    n_class + 1))
             y_true_noisy = (y_indicator.toarray()
