@@ -12,11 +12,12 @@ covariance estimator (the Minimum Covariance Determinant).
 #
 # License: BSD 3 clause
 
+import warnings
 import numpy as np
 import scipy as sp
 from . import MinCovDet
-from ..utils import deprecated
 from ..base import ClassifierMixin
+from ..utils.validation import check_is_fitted
 
 
 class OutlierDetectionMixin(object):
@@ -37,7 +38,6 @@ class OutlierDetectionMixin(object):
     """
     def __init__(self, contamination=0.1):
         self.contamination = contamination
-        self.threshold = None
 
     def decision_function(self, X, raw_values=False):
         """Compute the decision function of the given observations.
@@ -63,14 +63,14 @@ class OutlierDetectionMixin(object):
             such as the One-Class SVM.
 
         """
+        check_is_fitted(self, 'threshold_')
         mahal_dist = self.mahalanobis(X)
         if raw_values:
             decision = mahal_dist
         else:
-            if self.threshold is None:
-                raise Exception("Please fit data before predicting")
+            check_is_fitted(self, 'threshold_')
             transformed_mahal_dist = mahal_dist ** 0.33
-            decision = self.threshold ** 0.33 - transformed_mahal_dist
+            decision = self.threshold_ ** 0.33 - transformed_mahal_dist
 
         return decision
 
@@ -91,38 +91,46 @@ class OutlierDetectionMixin(object):
             The values of the less outlying point's decision function.
 
         """
-        if self.threshold is None:
-            raise Exception("Please fit data before predicting")
+        check_is_fitted(self, 'threshold_')
         is_inlier = -np.ones(X.shape[0], dtype=int)
         if self.contamination is not None:
             values = self.decision_function(X, raw_values=True)
-            is_inlier[values <= self.threshold] = 1
+            is_inlier[values <= self.threshold_] = 1
         else:
             raise NotImplementedError("You must provide a contamination rate.")
 
         return is_inlier
 
+    @property
+    def threshold(self):
+        warnings.warn(("The threshold attribute is renamed to threshold_ from "
+                       "0.16 onwards and will be removed in 0.18"),
+                      DeprecationWarning, stacklevel=1)
+        return getattr(self, 'threshold_', None)
+
 
 class EllipticEnvelope(ClassifierMixin, OutlierDetectionMixin, MinCovDet):
     """An object for detecting outliers in a Gaussian distributed dataset.
 
+    Read more in the :ref:`User Guide <outlier_detection>`.
+
     Attributes
     ----------
     `contamination` : float, 0. < contamination < 0.5
       The amount of contamination of the data set, i.e. the proportion of \
       outliers in the data set.
 
-    `location_` : array-like, shape (n_features,)
+    location_ : array-like, shape (n_features,)
         Estimated robust location
 
-    `covariance_` : array-like, shape (n_features, n_features)
+    covariance_ : array-like, shape (n_features, n_features)
         Estimated robust covariance matrix
 
-    `precision_` : array-like, shape (n_features, n_features)
+    precision_ : array-like, shape (n_features, n_features)
         Estimated pseudo inverse matrix.
         (stored only if store_precision is True)
 
-    `support_` : array-like, shape (n_samples,)
+    support_ : array-like, shape (n_samples,)
         A mask of the observations that have been used to compute the
         robust estimates of location and shape.
 
@@ -176,16 +184,7 @@ class EllipticEnvelope(ClassifierMixin, OutlierDetectionMixin, MinCovDet):
         OutlierDetectionMixin.__init__(self, contamination=contamination)
 
     def fit(self, X, y=None):
-        """
-        """
         MinCovDet.fit(self, X)
-        self.threshold = sp.stats.scoreatpercentile(
+        self.threshold_ = sp.stats.scoreatpercentile(
             self.dist_, 100. * (1. - self.contamination))
-
         return self
-
-
-# Deprecated classes
-@deprecated("Use EllipticEnvelope instead. To be removed in 0.13.")
-class EllipticEnvelop(EllipticEnvelope):
-    pass
