@@ -24,9 +24,12 @@ except ImportError:
 
 from sklearn.datasets import load_lfw_pairs
 from sklearn.datasets import load_lfw_people
+from sklearn.datasets import fetch_lfw_pairs
+from sklearn.datasets import fetch_lfw_people
 
 from sklearn.utils.testing import assert_array_equal
 from sklearn.utils.testing import assert_equal
+from sklearn.utils.testing import assert_warns_message
 from sklearn.utils.testing import SkipTest
 from sklearn.utils.testing import raises
 
@@ -49,7 +52,7 @@ FAKE_NAMES = [
 def setup_module():
     """Test fixture run once and common to all tests of this module"""
     if imsave is None:
-        raise SkipTest
+        raise SkipTest("PIL not installed.")
 
     if not os.path.exists(LFW_HOME):
         os.makedirs(LFW_HOME)
@@ -72,8 +75,7 @@ def setup_module():
             try:
                 imsave(file_path, uniface)
             except ImportError:
-                # PIL is not properly installed, skip those tests
-                raise SkipTest
+                raise SkipTest("PIL not installed")
 
     # add some random file pollution to test robustness
     with open(os.path.join(LFW_HOME, 'lfw_funneled', '.test.swp'), 'wb') as f:
@@ -113,12 +115,20 @@ def teardown_module():
 
 @raises(IOError)
 def test_load_empty_lfw_people():
-    load_lfw_people(data_home=SCIKIT_LEARN_EMPTY_DATA)
+    fetch_lfw_people(data_home=SCIKIT_LEARN_EMPTY_DATA, download_if_missing=False)
+
+
+def test_load_lfw_people_deprecation():
+    msg = ("Function 'load_lfw_people' has been deprecated in 0.17 and will be "
+           "removed in 0.19."
+           "Use fetch_lfw_people(download_if_missing=False) instead.")
+    assert_warns_message(DeprecationWarning, msg, load_lfw_people,
+                         data_home=SCIKIT_LEARN_DATA)
 
 
 def test_load_fake_lfw_people():
-    lfw_people = load_lfw_people(data_home=SCIKIT_LEARN_DATA,
-                                 min_faces_per_person=3)
+    lfw_people = fetch_lfw_people(data_home=SCIKIT_LEARN_DATA,
+                                  min_faces_per_person=3, download_if_missing=False)
 
     # The data is croped around the center as a rectangular bounding box
     # arounthe the face. Colors are converted to gray levels:
@@ -134,8 +144,8 @@ def test_load_fake_lfw_people():
 
     # It is possible to ask for the original data without any croping or color
     # conversion and not limit on the number of picture per person
-    lfw_people = load_lfw_people(data_home=SCIKIT_LEARN_DATA,
-                                 resize=None, slice_=None, color=True)
+    lfw_people = fetch_lfw_people(data_home=SCIKIT_LEARN_DATA,
+                                  resize=None, slice_=None, color=True, download_if_missing=False)
     assert_equal(lfw_people.images.shape, (17, 250, 250, 3))
 
     # the ids and class names are the same as previously
@@ -148,16 +158,24 @@ def test_load_fake_lfw_people():
 
 @raises(ValueError)
 def test_load_fake_lfw_people_too_restrictive():
-    load_lfw_people(data_home=SCIKIT_LEARN_DATA, min_faces_per_person=100)
+    fetch_lfw_people(data_home=SCIKIT_LEARN_DATA, min_faces_per_person=100, download_if_missing=False)
 
 
 @raises(IOError)
 def test_load_empty_lfw_pairs():
-    load_lfw_pairs(data_home=SCIKIT_LEARN_EMPTY_DATA)
+    fetch_lfw_pairs(data_home=SCIKIT_LEARN_EMPTY_DATA, download_if_missing=False)
+
+
+def test_load_lfw_pairs_deprecation():
+    msg = ("Function 'load_lfw_pairs' has been deprecated in 0.17 and will be "
+           "removed in 0.19."
+           "Use fetch_lfw_pairs(download_if_missing=False) instead.")
+    assert_warns_message(DeprecationWarning, msg, load_lfw_pairs,
+                         data_home=SCIKIT_LEARN_DATA)
 
 
 def test_load_fake_lfw_pairs():
-    lfw_pairs_train = load_lfw_pairs(data_home=SCIKIT_LEARN_DATA)
+    lfw_pairs_train = fetch_lfw_pairs(data_home=SCIKIT_LEARN_DATA, download_if_missing=False)
 
     # The data is croped around the center as a rectangular bounding box
     # arounthe the face. Colors are converted to gray levels:
@@ -172,8 +190,8 @@ def test_load_fake_lfw_pairs():
 
     # It is possible to ask for the original data without any croping or color
     # conversion
-    lfw_pairs_train = load_lfw_pairs(data_home=SCIKIT_LEARN_DATA,
-                                     resize=None, slice_=None, color=True)
+    lfw_pairs_train = fetch_lfw_pairs(data_home=SCIKIT_LEARN_DATA,
+                                      resize=None, slice_=None, color=True, download_if_missing=False)
     assert_equal(lfw_pairs_train.pairs.shape, (10, 2, 250, 250, 3))
 
     # the ids and class names are the same as previously
