@@ -16,6 +16,7 @@ from .dict_learning import (dict_learning, dict_learning_online, sparse_encode,
                             SparseCoder)
 from .factor_analysis import FactorAnalysis
 from ..utils.extmath import randomized_svd
+from .online_lda import LatentDirichletAllocation
 
 __all__ = ['DictionaryLearning',
            'FastICA',
@@ -35,4 +36,5 @@ __all__ = ['DictionaryLearning',
            'randomized_svd',
            'sparse_encode',
            'FactorAnalysis',
-           'TruncatedSVD']
+           'TruncatedSVD',
+           'LatentDirichletAllocation']
