@@ -1,15 +1,17 @@
 """Testing for the boost module (sklearn.ensemble.boost)."""
 
 import numpy as np
-from numpy.testing import assert_array_equal, assert_array_less
-from numpy.testing import assert_array_almost_equal
-from numpy.testing import assert_equal
-from nose.tools import assert_raises
+from sklearn.utils.testing import assert_array_equal, assert_array_less
+from sklearn.utils.testing import assert_array_almost_equal
+from sklearn.utils.testing import assert_equal, assert_true
+from sklearn.utils.testing import assert_raises, assert_raises_regexp
 
+from sklearn.base import BaseEstimator
 from sklearn.cross_validation import train_test_split
 from sklearn.grid_search import GridSearchCV
 from sklearn.ensemble import AdaBoostClassifier
 from sklearn.ensemble import AdaBoostRegressor
+from sklearn.ensemble import weight_boosting
 from scipy.sparse import csc_matrix
 from scipy.sparse import csr_matrix
 from scipy.sparse import coo_matrix
@@ -19,7 +21,6 @@ from sklearn.svm import SVC, SVR
 from sklearn.tree import DecisionTreeClassifier, DecisionTreeRegressor
 from sklearn.utils import shuffle
 from sklearn import datasets
-import time
 
 
 # Common random state
@@ -44,8 +45,37 @@ boston.data, boston.target = shuffle(boston.data, boston.target,
                                      random_state=rng)
 
 
+def test_samme_proba():
+    # Test the `_samme_proba` helper function.
+
+    # Define some example (bad) `predict_proba` output.
+    probs = np.array([[1, 1e-6, 0],
+                      [0.19, 0.6, 0.2],
+                      [-999, 0.51, 0.5],
+                      [1e-6, 1, 1e-9]])
+    probs /= np.abs(probs.sum(axis=1))[:, np.newaxis]
+
+    # _samme_proba calls estimator.predict_proba.
+    # Make a mock object so I can control what gets returned.
+    class MockEstimator(object):
+        def predict_proba(self, X):
+            assert_array_equal(X.shape, probs.shape)
+            return probs
+    mock = MockEstimator()
+
+    samme_proba = weight_boosting._samme_proba(mock, 3, np.ones_like(probs))
+
+    assert_array_equal(samme_proba.shape, probs.shape)
+    assert_true(np.isfinite(samme_proba).all())
+
+    # Make sure that the correct elements come out as smallest --
+    # `_samme_proba` should preserve the ordering in each example.
+    assert_array_equal(np.argmin(samme_proba, axis=1), [2, 0, 0, 2])
+    assert_array_equal(np.argmax(samme_proba, axis=1), [0, 1, 1, 1])
+
+
 def test_classification_toy():
-    """Check classification on a toy dataset."""
+    # Check classification on a toy dataset.
     for alg in ['SAMME', 'SAMME.R']:
         clf = AdaBoostClassifier(algorithm=alg, random_state=0)
         clf.fit(X, y_class)
@@ -56,14 +86,14 @@ def test_classification_toy():
 
 
 def test_regression_toy():
-    """Check classification on a toy dataset."""
+    # Check classification on a toy dataset.
     clf = AdaBoostRegressor(random_state=0)
     clf.fit(X, y_regr)
     assert_array_equal(clf.predict(T), y_t_regr)
 
 
 def test_iris():
-    """Check consistency on dataset iris."""
+    # Check consistency on dataset iris.
     classes = np.unique(iris.target)
     clf_samme = prob_samme = None
 
@@ -92,7 +122,7 @@ def test_iris():
 
 
 def test_boston():
-    """Check consistency on dataset boston house prices."""
+    # Check consistency on dataset boston house prices.
     clf = AdaBoostRegressor(random_state=0)
     clf.fit(boston.data, boston.target)
     score = clf.score(boston.data, boston.target)
@@ -100,7 +130,7 @@ def test_boston():
 
 
 def test_staged_predict():
-    """Check staged predictions."""
+    # Check staged predictions.
     rng = np.random.RandomState(0)
     iris_weights = rng.randint(10, size=iris.target.shape)
     boston_weights = rng.randint(10, size=boston.target.shape)
@@ -144,7 +174,7 @@ def test_staged_predict():
 
 
 def test_gridsearch():
-    """Check that base trees can be grid-searched."""
+    # Check that base trees can be grid-searched.
     # AdaBoost classification
     boost = AdaBoostClassifier(base_estimator=DecisionTreeClassifier())
     parameters = {'n_estimators': (1, 2),
@@ -163,7 +193,7 @@ def test_gridsearch():
 
 
 def test_pickle():
-    """Check pickability."""
+    # Check pickability.
     import pickle
 
     # Adaboost classifier
@@ -191,7 +221,7 @@ def test_pickle():
 
 
 def test_importances():
-    """Check variable importances."""
+    # Check variable importances.
     X, y = datasets.make_classification(n_samples=2000,
                                         n_features=10,
                                         n_informative=3,
@@ -212,7 +242,7 @@ def test_importances():
 
 
 def test_error():
-    """Test that it gives proper exception on deficient input."""
+    # Test that it gives proper exception on deficient input.
     assert_raises(ValueError,
                   AdaBoostClassifier(learning_rate=-1).fit,
                   X, y_class)
@@ -227,7 +257,7 @@ def test_error():
 
 
 def test_base_estimator():
-    """Test different base estimators."""
+    # Test different base estimators.
     from sklearn.ensemble import RandomForestClassifier
     from sklearn.svm import SVC
 
@@ -248,9 +278,30 @@ def test_base_estimator():
     clf = AdaBoostRegressor(SVR(), random_state=0)
     clf.fit(X, y_regr)
 
+    # Check that an empty discrete ensemble fails in fit, not predict.
+    X_fail = [[1, 1], [1, 1], [1, 1], [1, 1]]
+    y_fail = ["foo", "bar", 1, 2]
+    clf = AdaBoostClassifier(SVC(), algorithm="SAMME")
+    assert_raises_regexp(ValueError, "worse than random",
+                         clf.fit, X_fail, y_fail)
+
+
+def test_sample_weight_missing():
+    from sklearn.linear_model import LogisticRegression
+    from sklearn.cluster import KMeans
+
+    clf = AdaBoostClassifier(LogisticRegression(), algorithm="SAMME")
+    assert_raises(ValueError, clf.fit, X, y_regr)
+
+    clf = AdaBoostClassifier(KMeans(), algorithm="SAMME")
+    assert_raises(ValueError, clf.fit, X, y_regr)
+
+    clf = AdaBoostRegressor(KMeans())
+    assert_raises(ValueError, clf.fit, X, y_regr)
+
 
 def test_sparse_classification():
-    """Check classification with sparse input."""
+    # Check classification with sparse input.
 
     class CustomSVC(SVC):
         """SVC variant that records the nature of the training set."""
@@ -261,9 +312,8 @@ def test_sparse_classification():
             self.data_type_ = type(X)
             return self
 
-    X, y = datasets.make_multilabel_classification(n_classes=1, n_samples=100,
-                                                   n_features=50,
-                                                   return_indicator=True,
+    X, y = datasets.make_multilabel_classification(n_classes=1, n_samples=15,
+                                                   n_features=5,
                                                    random_state=42)
     # Flatten y to a 1d array
     y = np.ravel(y)
@@ -293,7 +343,6 @@ def test_sparse_classification():
         sparse_results = sparse_classifier.predict(X_test_sparse)
         dense_results = dense_classifier.predict(X_test)
         assert_array_equal(sparse_results, dense_results)
-        sparse_y_pred, dense_y_pred = sparse_results, dense_results
 
         # decision_function
         sparse_results = sparse_classifier.decision_function(X_test_sparse)
@@ -342,7 +391,6 @@ def test_sparse_classification():
             assert_array_equal(sprase_res, dense_res)
 
         # Verify sparsity of data is maintained during training
-        sparse_type = type(X_train_sparse)
         types = [i.data_type_ for i in sparse_classifier.estimators_]
 
         assert all([(t == csc_matrix or t == csr_matrix)
@@ -350,7 +398,7 @@ def test_sparse_classification():
 
 
 def test_sparse_regression():
-    """Check regression with sparse input."""
+    # Check regression with sparse input.
 
     class CustomSVR(SVR):
         """SVR variant that records the nature of the training set."""
@@ -361,7 +409,7 @@ def test_sparse_regression():
             self.data_type_ = type(X)
             return self
 
-    X, y = datasets.make_regression(n_samples=100, n_features=50, n_targets=1,
+    X, y = datasets.make_regression(n_samples=15, n_features=50, n_targets=1,
                                     random_state=42)
 
     X_train, X_test, y_train, y_test = train_test_split(X, y, random_state=0)
@@ -373,13 +421,13 @@ def test_sparse_regression():
 
         # Trained on sparse format
         sparse_classifier = AdaBoostRegressor(
-            base_estimator=CustomSVR(probability=True),
+            base_estimator=CustomSVR(),
             random_state=1
         ).fit(X_train_sparse, y_train)
 
         # Trained on dense format
         dense_classifier = dense_results = AdaBoostRegressor(
-            base_estimator=CustomSVR(probability=True),
+            base_estimator=CustomSVR(),
             random_state=1
         ).fit(X_train, y_train)
 
@@ -394,13 +442,27 @@ def test_sparse_regression():
         for sprase_res, dense_res in zip(sparse_results, dense_results):
             assert_array_equal(sprase_res, dense_res)
 
-        sparse_type = type(X_train_sparse)
         types = [i.data_type_ for i in sparse_classifier.estimators_]
 
         assert all([(t == csc_matrix or t == csr_matrix)
                    for t in types])
 
 
-if __name__ == "__main__":
-    import nose
-    nose.runmodule()
+def test_sample_weight_adaboost_regressor():
+    """
+    AdaBoostRegressor should work without sample_weights in the base estimator
+
+    The random weighted sampling is done internally in the _boost method in
+    AdaBoostRegressor.
+    """
+    class DummyEstimator(BaseEstimator):
+
+        def fit(self, X, y):
+            pass
+
+        def predict(self, X):
+            return np.zeros(X.shape[0])
+
+    boost = AdaBoostRegressor(DummyEstimator(), n_estimators=3)
+    boost.fit(X, y_regr)
+    assert_equal(len(boost.estimator_weights_), len(boost.estimator_errors_))
