@@ -1,4 +1,5 @@
-# Author: Lars Buitinck <L.J.Buitinck@uva.nl>
+# Authors: Lars Buitinck <L.J.Buitinck@uva.nl>
+#          Dan Blanchard <dblanchard@ets.org>
 # License: BSD 3 clause
 
 from random import Random
@@ -20,19 +21,27 @@ def test_dictvectorizer():
 
     for sparse in (True, False):
         for dtype in (int, np.float32, np.int16):
-            v = DictVectorizer(sparse=sparse, dtype=dtype)
-            X = v.fit_transform(D)
+            for sort in (True, False):
+                for iterable in (True, False):
+                    v = DictVectorizer(sparse=sparse, dtype=dtype, sort=sort)
+                    X = v.fit_transform(iter(D) if iterable else D)
 
-            assert_equal(sp.issparse(X), sparse)
-            assert_equal(X.shape, (3, 5))
-            assert_equal(X.sum(), 14)
-            assert_equal(v.inverse_transform(X), D)
+                    assert_equal(sp.issparse(X), sparse)
+                    assert_equal(X.shape, (3, 5))
+                    assert_equal(X.sum(), 14)
+                    assert_equal(v.inverse_transform(X), D)
 
-            if sparse:
-                # CSR matrices can't be compared for equality
-                assert_array_equal(X.A, v.transform(D).A)
-            else:
-                assert_array_equal(X, v.transform(D))
+                    if sparse:
+                        # CSR matrices can't be compared for equality
+                        assert_array_equal(X.A, v.transform(iter(D) if iterable
+                                                            else D).A)
+                    else:
+                        assert_array_equal(X, v.transform(iter(D) if iterable
+                                                          else D))
+
+                    if sort:
+                        assert_equal(v.feature_names_,
+                                     sorted(v.feature_names_))
 
 
 def test_feature_selection():
