@@ -9,10 +9,10 @@ from scipy import ndimage
 from nose.tools import assert_equal, assert_true
 from numpy.testing import assert_raises
 
-from ..image import img_to_graph, grid_to_graph
-from ..image import (extract_patches_2d, reconstruct_from_patches_2d,
-                     PatchExtractor, extract_patches)
-from ...utils.graph import connected_components
+from sklearn.feature_extraction.image import (
+    img_to_graph, grid_to_graph, extract_patches_2d,
+    reconstruct_from_patches_2d, PatchExtractor, extract_patches)
+from sklearn.utils.graph import connected_components
 
 
 def test_img_to_graph():
@@ -282,6 +282,9 @@ def test_extract_patches_square():
     assert_true(patches.shape == (expected_n_patches[0], expected_n_patches[1],
                                   p, p))
 
-if __name__ == '__main__':
-    import nose
-    nose.runmodule()
+
+def test_width_patch():
+    # width and height of the patch should be less than the image
+    x = np.array([[1, 2, 3], [4, 5, 6], [7, 8, 9]])
+    assert_raises(ValueError, extract_patches_2d, x, (4, 1))
+    assert_raises(ValueError, extract_patches_2d, x, (1, 4))
