@@ -6,16 +6,18 @@
 
 """Recursive feature elimination for feature ranking"""
 
+import warnings
 import numpy as np
-from ..utils import check_arrays, safe_sqr
+from ..utils import check_X_y, safe_sqr
+from ..utils.metaestimators import if_delegate_has_method
 from ..base import BaseEstimator
 from ..base import MetaEstimatorMixin
 from ..base import clone
 from ..base import is_classifier
-from ..cross_validation import _check_cv as check_cv
+from ..cross_validation import check_cv
 from ..cross_validation import _safe_split, _score
-from .base import SelectorMixin
 from ..metrics.scorer import check_scoring
+from .base import SelectorMixin
 
 
 class RFE(BaseEstimator, MetaEstimatorMixin, SelectorMixin):
@@ -30,6 +32,8 @@ class RFE(BaseEstimator, MetaEstimatorMixin, SelectorMixin):
     That procedure is recursively repeated on the pruned set until the desired
     number of features to select is eventually reached.
 
+    Read more in the :ref:`User Guide <rfe>`.
+
     Parameters
     ----------
     estimator : object
@@ -53,23 +57,26 @@ class RFE(BaseEstimator, MetaEstimatorMixin, SelectorMixin):
 
     estimator_params : dict
         Parameters for the external estimator.
-        Useful for doing grid searches when an `RFE` object is passed as an
-        argument to, e.g., a `sklearn.grid_search.GridSearchCV` object.
+        This attribute is deprecated as of version 0.16 and will be removed in
+        0.18. Use estimator initialisation or set_params method instead.
+
+    verbose : int, default=0
+        Controls verbosity of output.
 
     Attributes
     ----------
-    `n_features_` : int
+    n_features_ : int
         The number of selected features.
 
-    `support_` : array of shape [n_features]
+    support_ : array of shape [n_features]
         The mask of selected features.
 
-    `ranking_` : array of shape [n_features]
-        The feature ranking, such that `ranking_[i]` corresponds to the \
-        ranking position of the i-th feature. Selected (i.e., estimated \
+    ranking_ : array of shape [n_features]
+        The feature ranking, such that ``ranking_[i]`` corresponds to the
+        ranking position of the i-th feature. Selected (i.e., estimated
         best) features are assigned rank 1.
 
-    `estimator_` : object
+    estimator_ : object
         The external estimator fit on the reduced dataset.
 
     Examples
@@ -98,13 +105,17 @@ class RFE(BaseEstimator, MetaEstimatorMixin, SelectorMixin):
            Mach. Learn., 46(1-3), 389--422, 2002.
     """
     def __init__(self, estimator, n_features_to_select=None, step=1,
-                 estimator_params={}, verbose=0):
+                 estimator_params=None, verbose=0):
         self.estimator = estimator
         self.n_features_to_select = n_features_to_select
         self.step = step
         self.estimator_params = estimator_params
         self.verbose = verbose
 
+    @property
+    def _estimator_type(self):
+        return self.estimator._estimator_type
+
     def fit(self, X, y):
         """Fit the RFE model and then the underlying estimator on the selected
            features.
@@ -117,23 +128,37 @@ class RFE(BaseEstimator, MetaEstimatorMixin, SelectorMixin):
         y : array-like, shape = [n_samples]
             The target values.
         """
-        X, y = check_arrays(X, y, sparse_format="csc")
+        return self._fit(X, y)
+
+    def _fit(self, X, y, step_score=None):
+        X, y = check_X_y(X, y, "csc")
         # Initialization
         n_features = X.shape[1]
         if self.n_features_to_select is None:
-            n_features_to_select = n_features / 2
+            n_features_to_select = n_features // 2
         else:
             n_features_to_select = self.n_features_to_select
 
         if 0.0 < self.step < 1.0:
-            step = int(self.step * n_features)
+            step = int(max(1, self.step * n_features))
         else:
             step = int(self.step)
         if step <= 0:
             raise ValueError("Step must be >0")
 
+        if self.estimator_params is not None:
+            warnings.warn("The parameter 'estimator_params' is deprecated as "
+                          "of version 0.16 and will be removed in 0.18. The "
+                          "parameter is no longer necessary because the value "
+                          "is set via the estimator initialisation or "
+                          "set_params method.", DeprecationWarning)
+
         support_ = np.ones(n_features, dtype=np.bool)
         ranking_ = np.ones(n_features, dtype=np.int)
+
+        if step_score:
+            self.scores_ = []
+
         # Elimination
         while np.sum(support_) > n_features_to_select:
             # Remaining features
@@ -141,35 +166,60 @@ class RFE(BaseEstimator, MetaEstimatorMixin, SelectorMixin):
 
             # Rank the remaining features
             estimator = clone(self.estimator)
-            estimator.set_params(**self.estimator_params)
+            if self.estimator_params:
+                estimator.set_params(**self.estimator_params)
             if self.verbose > 0:
                 print("Fitting estimator with %d features." % np.sum(support_))
 
             estimator.fit(X[:, features], y)
 
-            if estimator.coef_.ndim > 1:
-                ranks = np.argsort(safe_sqr(estimator.coef_).sum(axis=0))
+            # Get coefs
+            if hasattr(estimator, 'coef_'):
+                coefs = estimator.coef_
+            elif hasattr(estimator, 'feature_importances_'):
+                coefs = estimator.feature_importances_
             else:
-                ranks = np.argsort(safe_sqr(estimator.coef_))
+                raise RuntimeError('The classifier does not expose '
+                                   '"coef_" or "feature_importances_" '
+                                   'attributes')
+
+            # Get ranks
+            if coefs.ndim > 1:
+                ranks = np.argsort(safe_sqr(coefs).sum(axis=0))
+            else:
+                ranks = np.argsort(safe_sqr(coefs))
 
             # for sparse case ranks is matrix
             ranks = np.ravel(ranks)
 
             # Eliminate the worse features
             threshold = min(step, np.sum(support_) - n_features_to_select)
+
+            # Compute step score on the previous selection iteration
+            # because 'estimator' must use features
+            # that have not been eliminated yet
+            if step_score:
+                self.scores_.append(step_score(estimator, features))
             support_[features[ranks][:threshold]] = False
             ranking_[np.logical_not(support_)] += 1
 
         # Set final attributes
+        features = np.arange(n_features)[support_]
         self.estimator_ = clone(self.estimator)
-        self.estimator_.set_params(**self.estimator_params)
-        self.estimator_.fit(X[:, support_], y)
+        if self.estimator_params:
+            self.estimator_.set_params(**self.estimator_params)
+        self.estimator_.fit(X[:, features], y)
+
+        # Compute step score when only n_features_to_select features left
+        if step_score:
+            self.scores_.append(step_score(self.estimator_, features))
         self.n_features_ = support_.sum()
         self.support_ = support_
         self.ranking_ = ranking_
 
         return self
 
+    @if_delegate_has_method(delegate='estimator')
     def predict(self, X):
         """Reduce X to the selected features and then predict using the
            underlying estimator.
@@ -186,6 +236,7 @@ class RFE(BaseEstimator, MetaEstimatorMixin, SelectorMixin):
         """
         return self.estimator_.predict(self.transform(X))
 
+    @if_delegate_has_method(delegate='estimator')
     def score(self, X, y):
         """Reduce X to the selected features and then return the score of the
            underlying estimator.
@@ -203,16 +254,24 @@ class RFE(BaseEstimator, MetaEstimatorMixin, SelectorMixin):
     def _get_support_mask(self):
         return self.support_
 
+    @if_delegate_has_method(delegate='estimator')
     def decision_function(self, X):
         return self.estimator_.decision_function(self.transform(X))
 
+    @if_delegate_has_method(delegate='estimator')
     def predict_proba(self, X):
         return self.estimator_.predict_proba(self.transform(X))
 
+    @if_delegate_has_method(delegate='estimator')
+    def predict_log_proba(self, X):
+        return self.estimator_.predict_log_proba(self.transform(X))
+
 
 class RFECV(RFE, MetaEstimatorMixin):
     """Feature ranking with recursive feature elimination and cross-validated
-       selection of the best number of features.
+    selection of the best number of features.
+
+    Read more in the :ref:`User Guide <rfe>`.
 
     Parameters
     ----------
@@ -231,11 +290,21 @@ class RFECV(RFE, MetaEstimatorMixin):
         If within (0.0, 1.0), then `step` corresponds to the percentage
         (rounded down) of features to remove at each iteration.
 
-    cv : int or cross-validation generator, optional (default=None)
-        If int, it is the number of folds.
-        If None, 3-fold cross-validation is performed by default.
-        Specific cross-validation objects can also be passed, see
-        `sklearn.cross_validation module` for details.
+    cv : int, cross-validation generator or an iterable, optional
+        Determines the cross-validation splitting strategy.
+        Possible inputs for cv are:
+
+        - None, to use the default 3-fold cross-validation,
+        - integer, to specify the number of folds.
+        - An object to be used as a cross-validation generator.
+        - An iterable yielding train/test splits.
+
+        For integer/None inputs, if ``y`` is binary or multiclass,
+        :class:`StratifiedKFold` used. If the estimator is a classifier
+        or if ``y`` is neither binary nor multiclass, :class:`KFold` is used.
+
+        Refer :ref:`User Guide <cross_validation>` for the various
+        cross-validation strategies that can be used here.
 
     scoring : string, callable or None, optional, default: None
         A string (see model evaluation documentation) or
@@ -244,34 +313,40 @@ class RFECV(RFE, MetaEstimatorMixin):
 
     estimator_params : dict
         Parameters for the external estimator.
-        Useful for doing grid searches when an `RFE` object is passed as an
-        argument to, e.g., a `sklearn.grid_search.GridSearchCV` object.
+        This attribute is deprecated as of version 0.16 and will be removed in
+        0.18. Use estimator initialisation or set_params method instead.
 
     verbose : int, default=0
         Controls verbosity of output.
 
     Attributes
     ----------
-    `n_features_` : int
+    n_features_ : int
         The number of selected features with cross-validation.
-    `support_` : array of shape [n_features]
+
+    support_ : array of shape [n_features]
         The mask of selected features.
 
-    `ranking_` : array of shape [n_features]
+    ranking_ : array of shape [n_features]
         The feature ranking, such that `ranking_[i]`
         corresponds to the ranking
         position of the i-th feature.
         Selected (i.e., estimated best)
         features are assigned rank 1.
 
-    `grid_scores_` : array of shape [n_subsets_of_features]
+    grid_scores_ : array of shape [n_subsets_of_features]
         The cross-validation scores such that
-        `grid_scores_[i]` corresponds to
+        ``grid_scores_[i]`` corresponds to
         the CV score of the i-th subset of features.
 
-    `estimator_` : object
+    estimator_ : object
         The external estimator fit on the reduced dataset.
 
+    Notes
+    -----
+    The size of ``grid_scores_`` is equal to ceil((n_features - 1) / step) + 1,
+    where step is the number of features removed at each iteration.
+
     Examples
     --------
     The following example shows how to retrieve the a-priori not known 5
@@ -298,12 +373,11 @@ class RFECV(RFE, MetaEstimatorMixin):
            Mach. Learn., 46(1-3), 389--422, 2002.
     """
     def __init__(self, estimator, step=1, cv=None, scoring=None,
-                 loss_func=None, estimator_params={}, verbose=0):
+                 estimator_params=None, verbose=0):
         self.estimator = estimator
         self.step = step
         self.cv = cv
         self.scoring = scoring
-        self.loss_func = loss_func
         self.estimator_params = estimator_params
         self.verbose = verbose
 
@@ -321,43 +395,46 @@ class RFECV(RFE, MetaEstimatorMixin):
             Target values (integers for classification, real numbers for
             regression).
         """
-        X, y = check_arrays(X, y, sparse_format="csr")
+        X, y = check_X_y(X, y, "csr")
+        if self.estimator_params is not None:
+            warnings.warn("The parameter 'estimator_params' is deprecated as "
+                          "of version 0.16 and will be removed in 0.18. "
+                          "The parameter is no longer necessary because the "
+                          "value is set via the estimator initialisation or "
+                          "set_params method.", DeprecationWarning)
         # Initialization
-        rfe = RFE(estimator=self.estimator, n_features_to_select=1,
-                  step=self.step, estimator_params=self.estimator_params,
-                  verbose=self.verbose - 1)
-
         cv = check_cv(self.cv, X, y, is_classifier(self.estimator))
-        scorer = check_scoring(self.estimator, scoring=self.scoring,
-                               loss_func=self.loss_func)
-        scores = np.zeros(X.shape[1])
+        scorer = check_scoring(self.estimator, scoring=self.scoring)
+        n_features = X.shape[1]
+        n_features_to_select = 1
+
+        # Determine the number of subsets of features
+        scores = []
 
         # Cross-validation
         for n, (train, test) in enumerate(cv):
             X_train, y_train = _safe_split(self.estimator, X, y, train)
             X_test, y_test = _safe_split(self.estimator, X, y, test, train)
 
-            # Compute a full ranking of the features
-            ranking_ = rfe.fit(X_train, y_train).ranking_
-            # Score each subset of features
-            for k in range(0, max(ranking_)):
-                mask = np.where(ranking_ <= k + 1)[0]
-                estimator = clone(self.estimator)
-                estimator.fit(X_train[:, mask], y_train)
-                score = _score(estimator, X_test[:, mask], y_test, scorer)
-
-                if self.verbose > 0:
-                    print("Finished fold with %d / %d feature ranks, score=%f"
-                          % (k + 1, max(ranking_), score))
-                scores[k] += score
-
-        # Pick the best number of features on average
-        k = np.argmax(scores)
-        best_score = scores[k]
+            rfe = RFE(estimator=self.estimator,
+                      n_features_to_select=n_features_to_select,
+                      step=self.step, estimator_params=self.estimator_params,
+                      verbose=self.verbose - 1)
 
+            rfe._fit(X_train, y_train, lambda estimator, features:
+                     _score(estimator, X_test[:, features], y_test, scorer))
+            scores.append(np.array(rfe.scores_[::-1]).reshape(1, -1))
+        scores = np.sum(np.concatenate(scores, 0), 0)
+        # The index in 'scores' when 'n_features' features are selected
+        n_feature_index = np.ceil((n_features - n_features_to_select) /
+                                  float(self.step))
+        n_features_to_select = max(n_features_to_select,
+                                   n_features - ((n_feature_index -
+                                                 np.argmax(scores)) *
+                                                 self.step))
         # Re-execute an elimination with best_k over the whole set
         rfe = RFE(estimator=self.estimator,
-                  n_features_to_select=k+1,
+                  n_features_to_select=n_features_to_select,
                   step=self.step, estimator_params=self.estimator_params)
 
         rfe.fit(X, y)
@@ -367,7 +444,8 @@ class RFECV(RFE, MetaEstimatorMixin):
         self.n_features_ = rfe.n_features_
         self.ranking_ = rfe.ranking_
         self.estimator_ = clone(self.estimator)
-        self.estimator_.set_params(**self.estimator_params)
+        if self.estimator_params:
+            self.estimator_.set_params(**self.estimator_params)
         self.estimator_.fit(self.transform(X), y)
 
         # Fixing a normalization error, n is equal to len(cv) - 1
