@@ -14,9 +14,7 @@ from sklearn.utils.testing import assert_array_almost_equal
 
 
 def test_bayesian_on_diabetes():
-    """
-    Test BayesianRidge on diabetes
-    """
+    # Test BayesianRidge on diabetes
     raise SkipTest("XFailed Test")
     diabetes = datasets.load_diabetes()
     X, y = diabetes.data, diabetes.target
@@ -37,9 +35,7 @@ def test_bayesian_on_diabetes():
 
 
 def test_toy_bayesian_ridge_object():
-    """
-    Test BayesianRidge on toy
-    """
+    # Test BayesianRidge on toy
     X = np.array([[1], [2], [6], [8], [10]])
     Y = np.array([1, 2, 6, 8, 10])
     clf = BayesianRidge(compute_score=True)
@@ -51,9 +47,7 @@ def test_toy_bayesian_ridge_object():
 
 
 def test_toy_ard_object():
-    """
-    Test BayesianRegression ARD classifier
-    """
+    # Test BayesianRegression ARD classifier
     X = np.array([[1], [2], [3]])
     Y = np.array([1, 2, 3])
     clf = ARDRegression(compute_score=True)
