@@ -3,15 +3,18 @@ from nose.tools import assert_equal
 import numpy as np
 from scipy import linalg
 
+from sklearn.cross_validation import train_test_split
 from sklearn.utils.testing import assert_array_almost_equal
 from sklearn.utils.testing import assert_true
 from sklearn.utils.testing import assert_less
 from sklearn.utils.testing import assert_greater
 from sklearn.utils.testing import assert_raises
-from sklearn.utils.testing import ignore_warnings, assert_warns_message
+from sklearn.utils.testing import ignore_warnings
 from sklearn.utils.testing import assert_no_warnings, assert_warns
+from sklearn.utils.testing import TempMemmap
 from sklearn.utils import ConvergenceWarning
 from sklearn import linear_model, datasets
+from sklearn.linear_model.least_angle import _lars_path_residues
 
 diabetes = datasets.load_diabetes()
 X, y = diabetes.data, diabetes.target
@@ -150,7 +153,8 @@ def test_no_path_precomputed():
 
 
 def test_no_path_all_precomputed():
-    # Test that the ``return_path=False`` option with Gram and Xy remains correct
+    # Test that the ``return_path=False`` option with Gram and Xy remains
+    # correct
     X, y = 3 * diabetes.data, diabetes.target
     G = np.dot(X.T, X)
     Xy = np.dot(X.T, y)
@@ -178,13 +182,13 @@ def test_rank_deficient_design():
     # deficient input data (with n_features < rank) in the same way
     # as coordinate descent Lasso
     y = [5, 0, 5]
-    for X in ([[5,   0],
-               [0,   5],
+    for X in ([[5, 0],
+               [0, 5],
                [10, 10]],
 
-              [[10,     10,  0],
-               [1e-32,   0,  0],
-               [0,       0,  1]],
+              [[10, 10, 0],
+               [1e-32, 0, 0],
+               [0, 0, 1]],
               ):
         # To be able to use the coefs to compute the objective function,
         # we need to turn off normalization
@@ -299,7 +303,6 @@ def test_lasso_lars_vs_lasso_cd_ill_conditioned():
     y = y.squeeze()
     lars_alphas, _, lars_coef = linear_model.lars_path(X, y, method='lasso')
 
-
     _, lasso_coef2, _ = linear_model.lasso_path(X, y,
                                                 alphas=lars_alphas,
                                                 tol=1e-6,
@@ -315,9 +318,9 @@ def test_lasso_lars_vs_lasso_cd_ill_conditioned2():
     # Note it used to be the case that Lars had to use the drop for good
     # strategy for this but this is no longer the case with the
     # equality_tolerance checks
-    X = [[1e20,  1e20,  0],
-         [-1e-32,  0,  0],
-         [1,       1,  1]]
+    X = [[1e20, 1e20, 0],
+         [-1e-32, 0, 0],
+         [1, 1, 1]]
     y = [10, 10, 1]
     alpha = .0001
 
@@ -330,7 +333,7 @@ def test_lasso_lars_vs_lasso_cd_ill_conditioned2():
     lars_coef_ = lars.coef_
     lars_obj = objective_function(lars_coef_)
 
-    coord_descent = linear_model.Lasso(alpha=alpha, tol=1e-10, normalize=False)
+    coord_descent = linear_model.Lasso(alpha=alpha, tol=1e-4, normalize=False)
     cd_coef_ = coord_descent.fit(X, y).coef_
     cd_obj = objective_function(cd_coef_)
 
@@ -357,6 +360,7 @@ def test_lars_n_nonzero_coefs(verbose=False):
     assert_equal(len(lars.alphas_), 7)
 
 
+@ignore_warnings
 def test_multitarget():
     # Assure that estimators receiving multidimensional y do the right thing
     X = diabetes.data
@@ -366,7 +370,7 @@ def test_multitarget():
     for estimator in (linear_model.LassoLars(), linear_model.Lars()):
         estimator.fit(X, Y)
         Y_pred = estimator.predict(X)
-        Y_dec = estimator.decision_function(X)
+        Y_dec = assert_warns(DeprecationWarning, estimator.decision_function, X)
         assert_array_almost_equal(Y_pred, Y_dec)
         alphas, active, coef, path = (estimator.alphas_, estimator.active_,
                                       estimator.coef_, estimator.coef_path_)
@@ -428,6 +432,113 @@ def test_no_warning_for_zero_mse():
     assert_true(np.any(np.isinf(lars.criterion_)))
 
 
-if __name__ == '__main__':
-    import nose
-    nose.runmodule()
+def test_lars_path_readonly_data():
+    # When using automated memory mapping on large input, the
+    # fold data is in read-only mode
+    # This is a non-regression test for:
+    # https://github.com/scikit-learn/scikit-learn/issues/4597
+    splitted_data = train_test_split(X, y, random_state=42)
+    with TempMemmap(splitted_data) as (X_train, X_test, y_train, y_test):
+        # The following should not fail despite copy=False
+        _lars_path_residues(X_train, y_train, X_test, y_test, copy=False)
+
+
+def test_lars_path_positive_constraint():
+    # this is the main test for the positive parameter on the lars_path method
+    # the estimator classes just make use of this function
+
+    # we do the test on the diabetes dataset
+
+    # ensure that we get negative coefficients when positive=False
+    # and all positive when positive=True
+    # for method 'lar' (default) and lasso
+    for method in ['lar', 'lasso']:
+        alpha, active, coefs = \
+            linear_model.lars_path(diabetes['data'], diabetes['target'],
+                                   return_path=True, method=method,
+                                   positive=False)
+        assert_true(coefs.min() < 0)
+
+        alpha, active, coefs = \
+            linear_model.lars_path(diabetes['data'], diabetes['target'],
+                                   return_path=True, method=method,
+                                   positive=True)
+        assert_true(coefs.min() >= 0)
+
+
+# now we gonna test the positive option for all estimator classes
+
+default_parameter = {'fit_intercept': False}
+
+estimator_parameter_map = {'Lars': {'n_nonzero_coefs': 5},
+                           'LassoLars': {'alpha': 0.1},
+                           'LarsCV': {},
+                           'LassoLarsCV': {},
+                           'LassoLarsIC': {}}
+
+
+def test_estimatorclasses_positive_constraint():
+    # testing the transmissibility for the positive option of all estimator
+    # classes in this same function here
+
+    for estname in estimator_parameter_map:
+        params = default_parameter.copy()
+        params.update(estimator_parameter_map[estname])
+        estimator = getattr(linear_model, estname)(positive=False, **params)
+        estimator.fit(diabetes['data'], diabetes['target'])
+        assert_true(estimator.coef_.min() < 0)
+        estimator = getattr(linear_model, estname)(positive=True, **params)
+        estimator.fit(diabetes['data'], diabetes['target'])
+        assert_true(min(estimator.coef_) >= 0)
+
+
+def test_lasso_lars_vs_lasso_cd_positive(verbose=False):
+    # Test that LassoLars and Lasso using coordinate descent give the
+    # same results when using the positive option
+
+    # This test is basically a copy of the above with additional positive
+    # option. However for the middle part, the comparison of coefficient values
+    # for a range of alphas, we had to make an adaptations. See below.
+
+    # not normalized data
+    X = 3 * diabetes.data
+
+    alphas, _, lasso_path = linear_model.lars_path(X, y, method='lasso',
+                                                   positive=True)
+    lasso_cd = linear_model.Lasso(fit_intercept=False, tol=1e-8, positive=True)
+    for c, a in zip(lasso_path.T, alphas):
+        if a == 0:
+            continue
+        lasso_cd.alpha = a
+        lasso_cd.fit(X, y)
+        error = linalg.norm(c - lasso_cd.coef_)
+        assert_less(error, 0.01)
+
+    # The range of alphas chosen for coefficient comparison here is restricted
+    # as compared with the above test without the positive option. This is due
+    # to the circumstance that the Lars-Lasso algorithm does not converge to
+    # the least-squares-solution for small alphas, see 'Least Angle Regression'
+    # by Efron et al 2004. The coefficients are typically in congruence up to
+    # the smallest alpha reached by the Lars-Lasso algorithm and start to
+    # diverge thereafter.  See
+    # https://gist.github.com/michigraber/7e7d7c75eca694c7a6ff
+
+    for alpha in np.linspace(6e-1, 1 - 1e-2, 20):
+        clf1 = linear_model.LassoLars(fit_intercept=False, alpha=alpha,
+                                      normalize=False, positive=True).fit(X, y)
+        clf2 = linear_model.Lasso(fit_intercept=False, alpha=alpha, tol=1e-8,
+                                  normalize=False, positive=True).fit(X, y)
+        err = linalg.norm(clf1.coef_ - clf2.coef_)
+        assert_less(err, 1e-3)
+
+    # normalized data
+    X = diabetes.data
+    alphas, _, lasso_path = linear_model.lars_path(X, y, method='lasso',
+                                                   positive=True)
+    lasso_cd = linear_model.Lasso(fit_intercept=False, normalize=True,
+                                  tol=1e-8, positive=True)
+    for c, a in zip(lasso_path.T[:-1], alphas[:-1]):  # don't include alpha=0
+        lasso_cd.alpha = a
+        lasso_cd.fit(X, y)
+        error = linalg.norm(c - lasso_cd.coef_)
+        assert_less(error, 0.01)
