@@ -23,7 +23,7 @@ from ..neighbors import kneighbors_graph
 
 
 def _graph_connected_component(graph, node_id):
-    """Find the largest graph connected components the contains one
+    """Find the largest graph connected components that contains one
     given node
 
     Parameters
@@ -38,8 +38,8 @@ def _graph_connected_component(graph, node_id):
     Returns
     -------
     connected_components_matrix : array-like, shape: (n_samples,)
-        An array of bool value indicates the indexes of the nodes
-        belong to the largest connected components of the given query
+        An array of bool value indicating the indexes of the nodes
+        belonging to the largest connected components of the given query
         node
     """
     connected_components_matrix = np.zeros(
@@ -121,11 +121,11 @@ def _set_diag(laplacian, value):
 def spectral_embedding(adjacency, n_components=8, eigen_solver=None,
                        random_state=None, eigen_tol=0.0,
                        norm_laplacian=True, drop_first=True):
-    """Project the sample on the first eigen vectors of the graph Laplacian.
+    """Project the sample on the first eigenvectors of the graph Laplacian.
 
     The adjacency matrix is used to compute a normalized graph Laplacian
-    whose spectrum (especially the eigen vectors associated to the
-    smallest eigen values) has an interpretation in terms of minimal
+    whose spectrum (especially the eigenvectors associated to the
+    smallest eigenvalues) has an interpretation in terms of minimal
     number of cuts necessary to split the graph into comparably sized
     components.
 
@@ -135,7 +135,9 @@ def spectral_embedding(adjacency, n_components=8, eigen_solver=None,
     heat kernel of a euclidean distance matrix or a k-NN matrix).
 
     However care must taken to always make the affinity matrix symmetric
-    so that the eigen vector decomposition works as expected.
+    so that the eigenvector decomposition works as expected.
+
+    Read more in the :ref:`User Guide <spectral_embedding>`.
 
     Parameters
     ----------
@@ -152,7 +154,7 @@ def spectral_embedding(adjacency, n_components=8, eigen_solver=None,
 
     random_state : int seed, RandomState instance, or None (default)
         A pseudo random number generator used for the initialization of the
-        lobpcg eigen vectors decomposition when eigen_solver == 'amg'.
+        lobpcg eigenvectors decomposition when eigen_solver == 'amg'.
         By default, arpack is used.
 
     eigen_tol : float, optional, default=0.0
@@ -263,7 +265,9 @@ def spectral_embedding(adjacency, n_components=8, eigen_solver=None,
         # problem.
         if not sparse.issparse(laplacian):
             warnings.warn("AMG works better for sparse matrices")
-        laplacian = laplacian.astype(np.float)  # lobpcg needs native floats
+        # lobpcg needs double precision floats
+        laplacian = check_array(laplacian, dtype=np.float64,
+                                accept_sparse=True)
         laplacian = _set_diag(laplacian, 1)
         ml = smoothed_aggregation_solver(check_array(laplacian, 'csr'))
         M = ml.aspreconditioner()
@@ -276,7 +280,9 @@ def spectral_embedding(adjacency, n_components=8, eigen_solver=None,
             raise ValueError
 
     elif eigen_solver == "lobpcg":
-        laplacian = laplacian.astype(np.float)  # lobpcg needs native floats
+        # lobpcg needs double precision floats
+        laplacian = check_array(laplacian, dtype=np.float64,
+                                accept_sparse=True)
         if n_nodes < 5 * n_components + 1:
             # see note above under arpack why lobpcg has problems with small
             # number of nodes
@@ -286,8 +292,6 @@ def spectral_embedding(adjacency, n_components=8, eigen_solver=None,
             lambdas, diffusion_map = eigh(laplacian)
             embedding = diffusion_map.T[:n_components] * dd
         else:
-            # lobpcg needs native floats
-            laplacian = laplacian.astype(np.float)
             laplacian = _set_diag(laplacian, 1)
             # We increase the number of eigenvectors requested, as lobpcg
             # doesn't behave well in low dimension
@@ -314,6 +318,8 @@ class SpectralEmbedding(BaseEstimator):
     The resulting transformation is given by the value of the
     eigenvectors for each data point.
 
+    Read more in the :ref:`User Guide <spectral_embedding>`.
+
     Parameters
     -----------
     n_components : integer, default: 2
@@ -326,7 +332,7 @@ class SpectralEmbedding(BaseEstimator):
 
     random_state : int seed, RandomState instance, or None, default : None
         A pseudo random number generator used for the initialization of the
-        lobpcg eigen vectors decomposition when eigen_solver == 'amg'.
+        lobpcg eigenvectors decomposition when eigen_solver == 'amg'.
 
     affinity : string or callable, default : "nearest_neighbors"
         How to construct the affinity matrix.
@@ -383,11 +389,11 @@ class SpectralEmbedding(BaseEstimator):
         return self.affinity == "precomputed"
 
     def _get_affinity_matrix(self, X, Y=None):
-        """Caclulate the affinity matrix from data
+        """Calculate the affinity matrix from data
         Parameters
         ----------
         X : array-like, shape (n_samples, n_features)
-            Training vector, where n_samples in the number of samples
+            Training vector, where n_samples is the number of samples
             and n_features is the number of features.
 
             If affinity is "precomputed"
@@ -432,7 +438,7 @@ class SpectralEmbedding(BaseEstimator):
         Parameters
         ----------
         X : array-like, shape (n_samples, n_features)
-            Training vector, where n_samples in the number of samples
+            Training vector, where n_samples is the number of samples
             and n_features is the number of features.
 
             If affinity is "precomputed"
@@ -445,6 +451,9 @@ class SpectralEmbedding(BaseEstimator):
         self : object
             Returns the instance itself.
         """
+
+        X = check_array(X, ensure_min_samples=2, estimator=self)
+
         random_state = check_random_state(self.random_state)
         if isinstance(self.affinity, six.string_types):
             if self.affinity not in set(("nearest_neighbors", "rbf",
@@ -469,7 +478,7 @@ class SpectralEmbedding(BaseEstimator):
         Parameters
         ----------
         X: array-like, shape (n_samples, n_features)
-            Training vector, where n_samples in the number of samples
+            Training vector, where n_samples is the number of samples
             and n_features is the number of features.
 
             If affinity is "precomputed"
