@@ -109,7 +109,7 @@ def test_non_consicutive_labels():
 
 def uniform_labelings_scores(score_func, n_samples, k_range, n_runs=10,
                              seed=42):
-    """Compute score for random uniform cluster labelings"""
+    # Compute score for random uniform cluster labelings
     random_labels = np.random.RandomState(seed).random_integers
     scores = np.zeros((len(k_range), n_runs))
     for i, k in enumerate(k_range):
@@ -121,7 +121,7 @@ def uniform_labelings_scores(score_func, n_samples, k_range, n_runs=10,
 
 
 def test_adjustment_for_chance():
-    """Check that adjusted scores are almost zero on random labels"""
+    # Check that adjusted scores are almost zero on random labels
     n_clusters_range = [2, 10, 50, 90]
     n_samples = 100
     n_runs = 10
@@ -134,7 +134,7 @@ def test_adjustment_for_chance():
 
 
 def test_adjusted_mutual_info_score():
-    """Compute the Adjusted Mutual Information and test against known values"""
+    # Compute the Adjusted Mutual Information and test against known values
     labels_a = np.array([1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3])
     labels_b = np.array([1, 1, 1, 1, 2, 1, 2, 2, 2, 2, 3, 1, 3, 3, 3, 2, 2])
     # Mutual information
@@ -177,8 +177,8 @@ def test_contingency_matrix():
 
 
 def test_exactly_zero_info_score():
-    """Check numerical stabability when information is exactly zero"""
-    for i in np.logspace(1, 4, 4):
+    # Check numerical stability when information is exactly zero
+    for i in np.logspace(1, 4, 4).astype(np.int):
         labels_a, labels_b = np.ones(i, dtype=np.int),\
             np.arange(i, dtype=np.int)
         assert_equal(normalized_mutual_info_score(labels_a, labels_b), 0.0)
@@ -188,7 +188,7 @@ def test_exactly_zero_info_score():
 
 
 def test_v_measure_and_mutual_information(seed=36):
-    """Check relation between v_measure, entropy and mutual information"""
+    # Check relation between v_measure, entropy and mutual information
     for i in np.logspace(1, 4, 4).astype(np.int):
         random_state = np.random.RandomState(seed)
         labels_a, labels_b = random_state.random_integers(0, 10, i),\
