@@ -29,6 +29,8 @@ def silhouette_score(X, labels, metric='euclidean', sample_size=None,
     overlapping clusters. Negative values generally indicate that a sample has
     been assigned to the wrong cluster, as a different cluster is more similar.
 
+    Read more in the :ref:`User Guide <silhouette_coefficient>`.
+
     Parameters
     ----------
     X : array [n_samples_a, n_samples_a] if metric == "precomputed", or, \
@@ -46,13 +48,14 @@ def silhouette_score(X, labels, metric='euclidean', sample_size=None,
         array itself, use ``metric="precomputed"``.
 
     sample_size : int or None
-        The size of the sample to use when computing the Silhouette
-        Coefficient. If ``sample_size is None``, no sampling is used.
+        The size of the sample to use when computing the Silhouette Coefficient 
+        on a random subset of the data. 
+        If ``sample_size is None``, no sampling is used.
 
     random_state : integer or numpy.RandomState, optional
-        The generator used to initialize the centers. If an integer is
-        given, it fixes the seed. Defaults to the global numpy random
-        number generator.
+        The generator used to randomly select a subset of samples if 
+        ``sample_size is not None``. If an integer is given, it fixes the seed.
+        Defaults to the global numpy random number generator.
 
     `**kwds` : optional keyword parameters
         Any further parameters are passed directly to the distance function.
@@ -113,6 +116,8 @@ def silhouette_samples(X, labels, metric='euclidean', **kwds):
     The best value is 1 and the worst value is -1. Values near 0 indicate
     overlapping clusters.
 
+    Read more in the :ref:`User Guide <silhouette_coefficient>`.
+
     Parameters
     ----------
     X : array [n_samples_a, n_samples_a] if metric == "precomputed", or, \
@@ -157,8 +162,7 @@ def silhouette_samples(X, labels, metric='euclidean', **kwds):
     B = np.array([_nearest_cluster_distance(distances[i], labels, i)
                   for i in range(n)])
     sil_samples = (B - A) / np.maximum(A, B)
-    # nan values are for clusters of size 1, and should be 0
-    return np.nan_to_num(sil_samples)
+    return sil_samples
 
 
 def _intra_cluster_distance(distances_row, labels, i):
@@ -183,6 +187,9 @@ def _intra_cluster_distance(distances_row, labels, i):
     """
     mask = labels == labels[i]
     mask[i] = False
+    if not np.any(mask):
+        # cluster of size 1
+        return 0
     a = np.mean(distances_row[mask])
     return a
 
