@@ -11,6 +11,7 @@ are supervised learning methods based on applying Bayes' theorem with strong
 #         Amit Aides <amitibo@tx.technion.ac.il>
 #         Yehuda Finkelstein <yehudaf@tx.technion.ac.il>
 #         Lars Buitinck <L.J.Buitinck@uva.nl>
+#         Jan Hendrik Metzen <jhm@informatik.uni-bremen.de>
 #         (parts based on earlier work by Mathieu Blondel)
 #
 # License: BSD 3 clause
@@ -24,9 +25,11 @@ from .base import BaseEstimator, ClassifierMixin
 from .preprocessing import binarize
 from .preprocessing import LabelBinarizer
 from .preprocessing import label_binarize
-from .utils import array2d, atleast2d_or_csr, column_or_1d, check_arrays
+from .utils import check_X_y, check_array
 from .utils.extmath import safe_sparse_dot, logsumexp
 from .utils.multiclass import _check_partial_fit_first_call
+from .utils.fixes import in1d
+from .utils.validation import check_is_fitted
 from .externals import six
 
 __all__ = ['BernoulliNB', 'GaussianNB', 'MultinomialNB']
@@ -104,15 +107,26 @@ class GaussianNB(BaseNB):
     """
     Gaussian Naive Bayes (GaussianNB)
 
+    Can perform online updates to model parameters via `partial_fit` method.
+    For details on algorithm used to update feature means and variance online,
+    see Stanford CS tech report STAN-CS-79-773 by Chan, Golub, and LeVeque:
+
+        http://i.stanford.edu/pub/cstr/reports/cs/tr/79/773/CS-TR-79-773.pdf
+
+    Read more in the :ref:`User Guide <gaussian_naive_bayes>`.
+
     Attributes
     ----------
-    `class_prior_` : array, shape = [n_classes]
+    class_prior_ : array, shape (n_classes,)
         probability of each class.
 
-    `theta_` : array, shape = [n_classes, n_features]
+    class_count_ : array, shape (n_classes,)
+        number of training samples observed in each class.
+
+    theta_ : array, shape (n_classes, n_features)
         mean of each feature per class
 
-    `sigma_` : array, shape = [n_classes, n_features]
+    sigma_ : array, shape (n_classes, n_features)
         variance of each feature per class
 
     Examples
@@ -126,47 +140,253 @@ class GaussianNB(BaseNB):
     GaussianNB()
     >>> print(clf.predict([[-0.8, -1]]))
     [1]
+    >>> clf_pf = GaussianNB()
+    >>> clf_pf.partial_fit(X, Y, np.unique(Y))
+    GaussianNB()
+    >>> print(clf_pf.predict([[-0.8, -1]]))
+    [1]
     """
 
-    def fit(self, X, y):
+    def fit(self, X, y, sample_weight=None):
         """Fit Gaussian Naive Bayes according to X, y
 
         Parameters
         ----------
-        X : array-like, shape = [n_samples, n_features]
+        X : array-like, shape (n_samples, n_features)
             Training vectors, where n_samples is the number of samples
             and n_features is the number of features.
 
-        y : array-like, shape = [n_samples]
+        y : array-like, shape (n_samples,)
             Target values.
 
+        sample_weight : array-like, shape (n_samples,), optional
+            Weights applied to individual samples (1. for unweighted).
+
+            .. versionadded:: 0.17
+               Gaussian Naive Bayes supports fitting with *sample_weight*.
+
         Returns
         -------
         self : object
             Returns self.
         """
+        X, y = check_X_y(X, y)
+        return self._partial_fit(X, y, np.unique(y), _refit=True,
+                                 sample_weight=sample_weight)
 
-        X, y = check_arrays(X, y, sparse_format='dense')
-        y = column_or_1d(y, warn=True)
+    @staticmethod
+    def _update_mean_variance(n_past, mu, var, X, sample_weight=None):
+        """Compute online update of Gaussian mean and variance.
 
-        n_samples, n_features = X.shape
+        Given starting sample count, mean, and variance, a new set of
+        points X, and optionally sample weights, return the updated mean and
+        variance. (NB - each dimension (column) in X is treated as independent
+        -- you get variance, not covariance).
 
-        self.classes_ = unique_y = np.unique(y)
-        n_classes = unique_y.shape[0]
+        Can take scalar mean and variance, or vector mean and variance to
+        simultaneously update a number of independent Gaussians.
 
-        self.theta_ = np.zeros((n_classes, n_features))
-        self.sigma_ = np.zeros((n_classes, n_features))
-        self.class_prior_ = np.zeros(n_classes)
-        epsilon = 1e-9
-        for i, y_i in enumerate(unique_y):
-            Xi = X[y == y_i, :]
-            self.theta_[i, :] = np.mean(Xi, axis=0)
-            self.sigma_[i, :] = np.var(Xi, axis=0) + epsilon
-            self.class_prior_[i] = np.float(Xi.shape[0]) / n_samples
+        See Stanford CS tech report STAN-CS-79-773 by Chan, Golub, and LeVeque:
+
+        http://i.stanford.edu/pub/cstr/reports/cs/tr/79/773/CS-TR-79-773.pdf
+
+        Parameters
+        ----------
+        n_past : int
+            Number of samples represented in old mean and variance. If sample
+            weights were given, this should contain the sum of sample
+            weights represented in old mean and variance.
+
+        mu : array-like, shape (number of Gaussians,)
+            Means for Gaussians in original set.
+
+        var : array-like, shape (number of Gaussians,)
+            Variances for Gaussians in original set.
+
+        sample_weight : array-like, shape (n_samples,), optional
+            Weights applied to individual samples (1. for unweighted).
+
+        Returns
+        -------
+        total_mu : array-like, shape (number of Gaussians,)
+            Updated mean for each Gaussian over the combined set.
+
+        total_var : array-like, shape (number of Gaussians,)
+            Updated variance for each Gaussian over the combined set.
+        """
+        if X.shape[0] == 0:
+            return mu, var
+
+        # Compute (potentially weighted) mean and variance of new datapoints
+        if sample_weight is not None:
+            n_new = float(sample_weight.sum())
+            new_mu = np.average(X, axis=0, weights=sample_weight / n_new)
+            new_var = np.average((X - new_mu) ** 2, axis=0,
+                                 weights=sample_weight / n_new)
+        else:
+            n_new = X.shape[0]
+            new_var = np.var(X, axis=0)
+            new_mu = np.mean(X, axis=0)
+
+        if n_past == 0:
+            return new_mu, new_var
+
+        n_total = float(n_past + n_new)
+
+        # Combine mean of old and new data, taking into consideration
+        # (weighted) number of observations
+        total_mu = (n_new * new_mu + n_past * mu) / n_total
+
+        # Combine variance of old and new data, taking into consideration
+        # (weighted) number of observations. This is achieved by combining
+        # the sum-of-squared-differences (ssd)
+        old_ssd = n_past * var
+        new_ssd = n_new * new_var
+        total_ssd = (old_ssd + new_ssd +
+                     (n_past / float(n_new * n_total)) *
+                     (n_new * mu - n_new * new_mu) ** 2)
+        total_var = total_ssd / n_total
+
+        return total_mu, total_var
+
+    def partial_fit(self, X, y, classes=None, sample_weight=None):
+        """Incremental fit on a batch of samples.
+
+        This method is expected to be called several times consecutively
+        on different chunks of a dataset so as to implement out-of-core
+        or online learning.
+
+        This is especially useful when the whole dataset is too big to fit in
+        memory at once.
+
+        This method has some performance and numerical stability overhead,
+        hence it is better to call partial_fit on chunks of data that are
+        as large as possible (as long as fitting in the memory budget) to
+        hide the overhead.
+
+        Parameters
+        ----------
+        X : array-like, shape (n_samples, n_features)
+            Training vectors, where n_samples is the number of samples and
+            n_features is the number of features.
+
+        y : array-like, shape (n_samples,)
+            Target values.
+
+        classes : array-like, shape (n_classes,)
+            List of all the classes that can possibly appear in the y vector.
+
+            Must be provided at the first call to partial_fit, can be omitted
+            in subsequent calls.
+
+        sample_weight : array-like, shape (n_samples,), optional
+            Weights applied to individual samples (1. for unweighted).
+
+            .. versionadded:: 0.17
+
+        Returns
+        -------
+        self : object
+            Returns self.
+        """
+        return self._partial_fit(X, y, classes, _refit=False,
+                                 sample_weight=sample_weight)
+
+    def _partial_fit(self, X, y, classes=None, _refit=False,
+                     sample_weight=None):
+        """Actual implementation of Gaussian NB fitting.
+
+        Parameters
+        ----------
+        X : array-like, shape (n_samples, n_features)
+            Training vectors, where n_samples is the number of samples and
+            n_features is the number of features.
+
+        y : array-like, shape (n_samples,)
+            Target values.
+
+        classes : array-like, shape (n_classes,)
+            List of all the classes that can possibly appear in the y vector.
+
+            Must be provided at the first call to partial_fit, can be omitted
+            in subsequent calls.
+
+        _refit: bool
+            If true, act as though this were the first time we called
+            _partial_fit (ie, throw away any past fitting and start over).
+
+        sample_weight : array-like, shape (n_samples,), optional
+            Weights applied to individual samples (1. for unweighted).
+
+        Returns
+        -------
+        self : object
+            Returns self.
+        """
+        X, y = check_X_y(X, y)
+
+        # If the ratio of data variance between dimensions is too small, it
+        # will cause numerical errors. To address this, we artificially
+        # boost the variance by epsilon, a small fraction of the standard
+        # deviation of the largest dimension.
+        epsilon = 1e-9 * np.var(X, axis=0).max()
+
+        if _refit:
+            self.classes_ = None
+
+        if _check_partial_fit_first_call(self, classes):
+            # This is the first call to partial_fit:
+            # initialize various cumulative counters
+            n_features = X.shape[1]
+            n_classes = len(self.classes_)
+            self.theta_ = np.zeros((n_classes, n_features))
+            self.sigma_ = np.zeros((n_classes, n_features))
+            self.class_prior_ = np.zeros(n_classes)
+            self.class_count_ = np.zeros(n_classes)
+        else:
+            if X.shape[1] != self.theta_.shape[1]:
+                msg = "Number of features %d does not match previous data %d."
+                raise ValueError(msg % (X.shape[1], self.theta_.shape[1]))
+            # Put epsilon back in each time
+            self.sigma_[:, :] -= epsilon
+
+        classes = self.classes_
+
+        unique_y = np.unique(y)
+        unique_y_in_classes = in1d(unique_y, classes)
+
+        if not np.all(unique_y_in_classes):
+            raise ValueError("The target label(s) %s in y do not exist in the "
+                             "initial classes %s" %
+                             (y[~unique_y_in_classes], classes))
+
+        for y_i in unique_y:
+            i = classes.searchsorted(y_i)
+            X_i = X[y == y_i, :]
+
+            if sample_weight is not None:
+                sw_i = sample_weight[y == y_i]
+                N_i = sw_i.sum()
+            else:
+                sw_i = None
+                N_i = X_i.shape[0]
+
+            new_theta, new_sigma = self._update_mean_variance(
+                self.class_count_[i], self.theta_[i, :], self.sigma_[i, :],
+                X_i, sw_i)
+
+            self.theta_[i, :] = new_theta
+            self.sigma_[i, :] = new_sigma
+            self.class_count_[i] += N_i
+
+        self.sigma_[:, :] += epsilon
+        self.class_prior_[:] = self.class_count_ / np.sum(self.class_count_)
         return self
 
     def _joint_log_likelihood(self, X):
-        X = array2d(X)
+        check_is_fitted(self, "classes_")
+
+        X = check_array(X)
         joint_log_likelihood = []
         for i in range(np.size(self.classes_)):
             jointi = np.log(self.class_prior_[i])
@@ -239,7 +459,7 @@ class BaseDiscreteNB(BaseNB):
         self : object
             Returns self.
         """
-        X = atleast2d_or_csr(X, dtype=np.float64)
+        X = check_array(X, accept_sparse='csr', dtype=np.float64)
         _, n_features = X.shape
 
         if _check_partial_fit_first_call(self, classes):
@@ -249,6 +469,9 @@ class BaseDiscreteNB(BaseNB):
             self.class_count_ = np.zeros(n_effective_classes, dtype=np.float64)
             self.feature_count_ = np.zeros((n_effective_classes, n_features),
                                            dtype=np.float64)
+        elif n_features != self.coef_.shape[1]:
+            msg = "Number of features %d does not match previous data %d."
+            raise ValueError(msg % (n_features, self.coef_.shape[-1]))
 
         Y = label_binarize(y, classes=self.classes_)
         if Y.shape[1] == 1:
@@ -260,10 +483,14 @@ class BaseDiscreteNB(BaseNB):
             msg = "X.shape[0]=%d and y.shape[0]=%d are incompatible."
             raise ValueError(msg % (X.shape[0], y.shape[0]))
 
-        # convert to float to support sample weight consistently
+        # label_binarize() returns arrays with dtype=np.int64.
+        # We convert it to np.float64 to support sample_weight consistently
         Y = Y.astype(np.float64)
         if sample_weight is not None:
-            Y *= array2d(sample_weight).T
+            sample_weight = np.atleast_2d(sample_weight)
+            Y *= check_array(sample_weight).T
+
+        class_prior = self.class_prior
 
         # Count raw events from data before updating the class log prior
         # and feature log probas
@@ -274,7 +501,7 @@ class BaseDiscreteNB(BaseNB):
         # calls to partial_fit and prior any call to predict[_[log_]proba]
         # to avoid computing the smooth log probas at each call to partial fit
         self._update_feature_log_prob()
-        self._update_class_log_prior()
+        self._update_class_log_prior(class_prior=class_prior)
         return self
 
     def fit(self, X, y, sample_weight=None):
@@ -297,8 +524,7 @@ class BaseDiscreteNB(BaseNB):
         self : object
             Returns self.
         """
-        X, y = check_arrays(X, y, sparse_format='csr')
-        y = column_or_1d(y, warn=True)
+        X, y = check_X_y(X, y, 'csr')
         _, n_features = X.shape
 
         labelbin = LabelBinarizer()
@@ -307,11 +533,13 @@ class BaseDiscreteNB(BaseNB):
         if Y.shape[1] == 1:
             Y = np.concatenate((1 - Y, Y), axis=1)
 
-        # convert to float to support sample weight consistently;
+        # LabelBinarizer().fit_transform() returns arrays with dtype=np.int64.
+        # We convert it to np.float64 to support sample_weight consistently;
         # this means we also don't have to cast X to floating point
         Y = Y.astype(np.float64)
         if sample_weight is not None:
-            Y *= array2d(sample_weight).T
+            sample_weight = np.atleast_2d(sample_weight)
+            Y *= check_array(sample_weight).T
 
         class_prior = self.class_prior
 
@@ -349,6 +577,8 @@ class MultinomialNB(BaseDiscreteNB):
     multinomial distribution normally requires integer feature counts. However,
     in practice, fractional counts such as tf-idf may also work.
 
+    Read more in the :ref:`User Guide <multinomial_naive_bayes>`.
+
     Parameters
     ----------
     alpha : float, optional (default=1.0)
@@ -365,26 +595,26 @@ class MultinomialNB(BaseDiscreteNB):
 
     Attributes
     ----------
-    `class_log_prior_` : array, shape (n_classes, )
+    class_log_prior_ : array, shape (n_classes, )
         Smoothed empirical log probability for each class.
 
-    `intercept_` : property
+    intercept_ : property
         Mirrors ``class_log_prior_`` for interpreting MultinomialNB
         as a linear model.
 
-    `feature_log_prob_`: array, shape (n_classes, n_features)
+    feature_log_prob_ : array, shape (n_classes, n_features)
         Empirical log probability of features
         given a class, ``P(x_i|y)``.
 
-    `coef_` : property
+    coef_ : property
         Mirrors ``feature_log_prob_`` for interpreting MultinomialNB
         as a linear model.
 
-    `class_count_` : array, shape (n_classes,)
+    class_count_ : array, shape (n_classes,)
         Number of samples encountered for each class during fitting. This
         value is weighted by the sample weight when provided.
 
-    `feature_count_` : array, shape (n_classes, n_features)
+    feature_count_ : array, shape (n_classes, n_features)
         Number of samples encountered for each (class, feature)
         during fitting. This value is weighted by the sample weight when
         provided.
@@ -398,7 +628,7 @@ class MultinomialNB(BaseDiscreteNB):
     >>> clf = MultinomialNB()
     >>> clf.fit(X, y)
     MultinomialNB(alpha=1.0, class_prior=None, fit_prior=True)
-    >>> print(clf.predict(X[2]))
+    >>> print(clf.predict(X[2:3]))
     [3]
 
     Notes
@@ -411,8 +641,7 @@ class MultinomialNB(BaseDiscreteNB):
     ----------
     C.D. Manning, P. Raghavan and H. Schuetze (2008). Introduction to
     Information Retrieval. Cambridge University Press, pp. 234-265.
-    http://nlp.stanford.edu/IR-book/html/htmledition/
-        naive-bayes-text-classification-1.html
+    http://nlp.stanford.edu/IR-book/html/htmledition/naive-bayes-text-classification-1.html
     """
 
     def __init__(self, alpha=1.0, fit_prior=True, class_prior=None):
@@ -437,7 +666,9 @@ class MultinomialNB(BaseDiscreteNB):
 
     def _joint_log_likelihood(self, X):
         """Calculate the posterior log probability of the samples X"""
-        X = atleast2d_or_csr(X)
+        check_is_fitted(self, "classes_")
+
+        X = check_array(X, accept_sparse='csr')
         return (safe_sparse_dot(X, self.feature_log_prob_.T)
                 + self.class_log_prior_)
 
@@ -449,6 +680,8 @@ class BernoulliNB(BaseDiscreteNB):
     difference is that while MultinomialNB works with occurrence counts,
     BernoulliNB is designed for binary/boolean features.
 
+    Read more in the :ref:`User Guide <bernoulli_naive_bayes>`.
+
     Parameters
     ----------
     alpha : float, optional (default=1.0)
@@ -469,17 +702,17 @@ class BernoulliNB(BaseDiscreteNB):
 
     Attributes
     ----------
-    `class_log_prior_` : array, shape = [n_classes]
+    class_log_prior_ : array, shape = [n_classes]
         Log probability of each class (smoothed).
 
-    `feature_log_prob_` : array, shape = [n_classes, n_features]
+    feature_log_prob_ : array, shape = [n_classes, n_features]
         Empirical log probability of features given a class, P(x_i|y).
 
-    `class_count_` : array, shape = [n_classes]
+    class_count_ : array, shape = [n_classes]
         Number of samples encountered for each class during fitting. This
         value is weighted by the sample weight when provided.
 
-    `feature_count_` : array, shape = [n_classes, n_features]
+    feature_count_ : array, shape = [n_classes, n_features]
         Number of samples encountered for each (class, feature)
         during fitting. This value is weighted by the sample weight when
         provided.
@@ -493,7 +726,7 @@ class BernoulliNB(BaseDiscreteNB):
     >>> clf = BernoulliNB()
     >>> clf.fit(X, Y)
     BernoulliNB(alpha=1.0, binarize=0.0, class_prior=None, fit_prior=True)
-    >>> print(clf.predict(X[2]))
+    >>> print(clf.predict(X[2:3]))
     [3]
 
     References
@@ -527,17 +760,17 @@ class BernoulliNB(BaseDiscreteNB):
 
     def _update_feature_log_prob(self):
         """Apply smoothing to raw counts and recompute log probabilities"""
-        n_classes = len(self.classes_)
         smoothed_fc = self.feature_count_ + self.alpha
-        smoothed_cc = self.class_count_ + self.alpha * n_classes
+        smoothed_cc = self.class_count_ + self.alpha * 2
 
         self.feature_log_prob_ = (np.log(smoothed_fc)
                                   - np.log(smoothed_cc.reshape(-1, 1)))
 
     def _joint_log_likelihood(self, X):
         """Calculate the posterior log probability of the samples X"""
+        check_is_fitted(self, "classes_")
 
-        X = atleast2d_or_csr(X)
+        X = check_array(X, accept_sparse='csr')
 
         if self.binarize is not None:
             X = binarize(X, threshold=self.binarize)
