@@ -12,7 +12,6 @@ from scipy.sparse import csr_matrix
 from scipy.sparse import coo_matrix
 
 from sklearn.random_projection import sparse_random_matrix
-from sklearn.utils.random import sample_without_replacement
 
 from sklearn.metrics import accuracy_score
 from sklearn.metrics import mean_squared_error
@@ -27,8 +26,12 @@ from sklearn.utils.testing import assert_greater
 from sklearn.utils.testing import assert_greater_equal
 from sklearn.utils.testing import assert_less
 from sklearn.utils.testing import assert_true
+from sklearn.utils.testing import assert_warns
 from sklearn.utils.testing import raises
+
 from sklearn.utils.validation import check_random_state
+from sklearn.utils.validation import NotFittedError
+from sklearn.utils.testing import ignore_warnings
 
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.tree import DecisionTreeRegressor
@@ -49,14 +52,14 @@ REG_CRITERIONS = ("mse", )
 CLF_TREES = {
     "DecisionTreeClassifier": DecisionTreeClassifier,
     "Presort-DecisionTreeClassifier": partial(DecisionTreeClassifier,
-                                              splitter="presort-best"),
+                                              presort=True),
     "ExtraTreeClassifier": ExtraTreeClassifier,
 }
 
 REG_TREES = {
     "DecisionTreeRegressor": DecisionTreeRegressor,
     "Presort-DecisionTreeRegressor": partial(DecisionTreeRegressor,
-                                             splitter="presort-best"),
+                                             presort=True),
     "ExtraTreeRegressor": ExtraTreeRegressor,
 }
 
@@ -64,8 +67,8 @@ ALL_TREES = dict()
 ALL_TREES.update(CLF_TREES)
 ALL_TREES.update(REG_TREES)
 
-SPARSE_TREES = [name for name, Tree in ALL_TREES.items()
-                if Tree().splitter in SPARSE_SPLITTERS]
+SPARSE_TREES = ["DecisionTreeClassifier", "DecisionTreeRegressor",
+                "ExtraTreeClassifier", "ExtraTreeRegressor"]
 
 
 X_small = np.array([
@@ -126,7 +129,7 @@ digits.target = digits.target[perm]
 
 random_state = check_random_state(0)
 X_multilabel, y_multilabel = datasets.make_multilabel_classification(
-    random_state=0, return_indicator=True, n_samples=30, n_features=10)
+    random_state=0, n_samples=30, n_features=10)
 
 X_sparse_pos = random_state.uniform(size=(20, 5))
 X_sparse_pos[X_sparse_pos <= 0.8] = 0.
@@ -376,7 +379,8 @@ def test_importances():
         assert_equal(importances.shape[0], 10, "Failed with {0}".format(name))
         assert_equal(n_important, 3, "Failed with {0}".format(name))
 
-        X_new = clf.transform(X, threshold="mean")
+        X_new = assert_warns(
+            DeprecationWarning, clf.transform, X, threshold="mean")
         assert_less(0, X_new.shape[1], "Failed with {0}".format(name))
         assert_less(X_new.shape[1], X.shape[1], "Failed with {0}".format(name))
 
@@ -494,10 +498,10 @@ def test_error():
     for name, TreeEstimator in CLF_TREES.items():
         # predict before fit
         est = TreeEstimator()
-        assert_raises(Exception, est.predict_proba, X)
+        assert_raises(NotFittedError, est.predict_proba, X)
 
         est.fit(X, y)
-        X2 = [-2, -1, 1]  # wrong feature shape for sample
+        X2 = [[-2, -1, 1]]  # wrong feature shape for sample
         assert_raises(ValueError, est.predict_proba, X2)
 
     for name, TreeEstimator in ALL_TREES.items():
@@ -527,7 +531,7 @@ def test_error():
 
         # predict before fitting
         est = TreeEstimator()
-        assert_raises(Exception, est.predict, T)
+        assert_raises(NotFittedError, est.predict, T)
 
         # predict on vector with different dims
         est.fit(X, y)
@@ -540,10 +544,16 @@ def test_error():
         est = TreeEstimator()
         est.fit(np.dot(X, Xt), y)
         assert_raises(ValueError, est.predict, X)
+        assert_raises(ValueError, est.apply, X)
 
         clf = TreeEstimator()
         clf.fit(X, y)
         assert_raises(ValueError, clf.predict, Xt)
+        assert_raises(ValueError, clf.apply, Xt)
+
+        # apply before fitting
+        est = TreeEstimator()
+        assert_raises(NotFittedError, est.apply, T)
 
 
 def test_min_samples_leaf():
@@ -759,7 +769,7 @@ def test_memory_layout():
         y = iris.target
         assert_array_equal(est.fit(X, y).predict(X), y)
 
-        if est.splitter in SPARSE_SPLITTERS:
+        if not est.presort:
             # csr matrix
             X = csr_matrix(iris.data, dtype=dtype)
             y = iris.target
@@ -813,7 +823,7 @@ def test_sample_weight():
     X = iris.data
     y = iris.target
 
-    duplicates = rng.randint(0, X.shape[0], 200)
+    duplicates = rng.randint(0, X.shape[0], 100)
 
     clf = DecisionTreeClassifier(random_state=1)
     clf.fit(X[duplicates], y[duplicates])
@@ -852,10 +862,10 @@ def check_class_weights(name):
     """Check class_weights resemble sample_weights behavior."""
     TreeClassifier = CLF_TREES[name]
 
-    # Iris is balanced, so no effect expected for using 'auto' weights
+    # Iris is balanced, so no effect expected for using 'balanced' weights
     clf1 = TreeClassifier(random_state=0)
     clf1.fit(iris.data, iris.target)
-    clf2 = TreeClassifier(class_weight='auto', random_state=0)
+    clf2 = TreeClassifier(class_weight='balanced', random_state=0)
     clf2.fit(iris.data, iris.target)
     assert_almost_equal(clf1.feature_importances_, clf2.feature_importances_)
 
@@ -869,7 +879,7 @@ def check_class_weights(name):
     clf3.fit(iris.data, iris_multi)
     assert_almost_equal(clf2.feature_importances_, clf3.feature_importances_)
     # Check against multi-output "auto" which should also have no effect
-    clf4 = TreeClassifier(class_weight='auto', random_state=0)
+    clf4 = TreeClassifier(class_weight='balanced', random_state=0)
     clf4.fit(iris.data, iris_multi)
     assert_almost_equal(clf3.feature_importances_, clf4.feature_importances_)
 
@@ -885,7 +895,7 @@ def check_class_weights(name):
 
     # Check that sample_weight and class_weight are multiplicative
     clf1 = TreeClassifier(random_state=0)
-    clf1.fit(iris.data, iris.target, sample_weight**2)
+    clf1.fit(iris.data, iris.target, sample_weight ** 2)
     clf2 = TreeClassifier(class_weight=class_weight, random_state=0)
     clf2.fit(iris.data, iris.target, sample_weight)
     assert_almost_equal(clf1.feature_importances_, clf2.feature_importances_)
@@ -999,7 +1009,7 @@ def test_big_input():
 
 
 def test_realloc():
-    from sklearn.tree._tree import _realloc_test
+    from sklearn.tree._utils import _realloc_test
     assert_raises(MemoryError, _realloc_test)
 
 
@@ -1208,6 +1218,8 @@ def check_explicit_sparse_zeros(tree, max_depth=3,
     Xs = (X_test, X_sparse_test)
     for X1, X2 in product(Xs, Xs):
         assert_array_almost_equal(s.tree_.apply(X1), d.tree_.apply(X2))
+        assert_array_almost_equal(s.apply(X1), d.apply(X2))
+        assert_array_almost_equal(s.apply(X1), s.tree_.apply(X1))
         assert_array_almost_equal(s.predict(X1), d.predict(X2))
 
         if tree in CLF_TREES:
@@ -1220,6 +1232,7 @@ def test_explicit_sparse_zeros():
         yield (check_explicit_sparse_zeros, tree)
 
 
+@ignore_warnings
 def check_raise_error_on_1d_input(name):
     TreeEstimator = ALL_TREES[name]
 
@@ -1231,9 +1244,10 @@ def check_raise_error_on_1d_input(name):
 
     est = TreeEstimator(random_state=0)
     est.fit(X_2d, y)
-    assert_raises(ValueError, est.predict, X)
+    assert_raises(ValueError, est.predict, [X])
 
 
+@ignore_warnings
 def test_1d_input():
     for name in ALL_TREES:
         yield check_raise_error_on_1d_input, name
@@ -1258,7 +1272,7 @@ def check_min_weight_leaf_split_level(name):
     sample_weight = [0.2, 0.2, 0.2, 0.2, 0.2]
     _check_min_weight_leaf_split_level(TreeEstimator, X, y, sample_weight)
 
-    if TreeEstimator().splitter in SPARSE_SPLITTERS:
+    if not TreeEstimator().presort:
         _check_min_weight_leaf_split_level(TreeEstimator, csc_matrix(X), y,
                                            sample_weight)
 
@@ -1266,3 +1280,47 @@ def check_min_weight_leaf_split_level(name):
 def test_min_weight_leaf_split_level():
     for name in ALL_TREES:
         yield check_min_weight_leaf_split_level, name
+
+
+def check_public_apply(name):
+    X_small32 = X_small.astype(tree._tree.DTYPE)
+
+    est = ALL_TREES[name]()
+    est.fit(X_small, y_small)
+    assert_array_equal(est.apply(X_small),
+                       est.tree_.apply(X_small32))
+
+
+def check_public_apply_sparse(name):
+    X_small32 = csr_matrix(X_small.astype(tree._tree.DTYPE))
+
+    est = ALL_TREES[name]()
+    est.fit(X_small, y_small)
+    assert_array_equal(est.apply(X_small),
+                       est.tree_.apply(X_small32))
+
+
+def test_public_apply():
+    for name in ALL_TREES:
+        yield (check_public_apply, name)
+
+    for name in SPARSE_TREES:
+        yield (check_public_apply_sparse, name)
+
+
+def check_presort_sparse(est, X, y):
+    assert_raises(ValueError, est.fit, X, y )
+
+def test_presort_sparse():
+    ests = (DecisionTreeClassifier(presort=True), 
+            DecisionTreeRegressor(presort=True))
+    sparse_matrices = (csr_matrix, csc_matrix, coo_matrix)
+
+    y, X = datasets.make_multilabel_classification(random_state=0,
+                                                   n_samples=50,
+                                                   n_features=1,
+                                                   n_classes=20)
+    y = y[:, 0]
+
+    for est, sparse_matrix in product(ests, sparse_matrices):
+        yield check_presort_sparse, est, sparse_matrix(X), y
