@@ -8,6 +8,7 @@ Extended math utilities.
 #          Lars Buitinck
 #          Stefan van der Walt
 #          Kyle Kastner
+#          Giorgio Patrini
 # License: BSD 3 clause
 
 from __future__ import division
@@ -18,7 +19,7 @@ import numpy as np
 from scipy import linalg
 from scipy.sparse import issparse
 
-from . import check_random_state, deprecated
+from . import check_random_state
 from .fixes import np_version
 from ._logistic_sigmoid import _log_logistic_sigmoid
 from ..externals.six.moves import xrange
@@ -287,8 +288,8 @@ def randomized_svd(M, n_components, n_oversamples=10, n_iter=0,
     n_random = n_components + n_oversamples
     n_samples, n_features = M.shape
 
-    if transpose == 'auto' and n_samples > n_features:
-        transpose = True
+    if transpose == 'auto':
+        transpose = n_samples < n_features
     if transpose:
         # this implementation is a bit faster with smaller shape[1]
         M = M.T
@@ -437,7 +438,7 @@ def pinvh(a, cond=None, rcond=None, lower=True):
         zero.
 
         If None or -1, suitable machine precision is used.
- 
+
     lower : boolean
         Whether the pertinent array data is taken from the lower or upper
         triangle of a. (Default: lower)
@@ -539,14 +540,14 @@ def svd_flip(u, v, u_based_decision=True):
     Parameters
     ----------
     u, v : ndarray
-        u and v are the output of `linalg.svd` or 
+        u and v are the output of `linalg.svd` or
         `sklearn.utils.extmath.randomized_svd`, with matching inner dimensions
         so one can compute `np.dot(u * s, v)`.
 
     u_based_decision : boolean, (default=True)
-        If True, use the columns of u as the basis for sign flipping. Otherwise,
-        use the rows of v. The choice of which variable to base the decision on
-        is generally algorithm dependent.
+        If True, use the columns of u as the basis for sign flipping.
+        Otherwise, use the rows of v. The choice of which variable to base the
+        decision on is generally algorithm dependent.
 
 
     Returns
@@ -569,14 +570,6 @@ def svd_flip(u, v, u_based_decision=True):
     return u, v
 
 
-@deprecated('to be removed in 0.17; use scipy.special.expit or log_logistic')
-def logistic_sigmoid(X, log=False, out=None):
-    """Logistic function, ``1 / (1 + e ** (-x))``, or its log."""
-    from .fixes import expit
-    fn = log_logistic if log else expit
-    return fn(X, out)
-
-
 def log_logistic(X, out=None):
     """Compute the log of the logistic function, ``log(1 / (1 + e ** -x))``.
 
@@ -590,15 +583,15 @@ def log_logistic(X, out=None):
 
     Parameters
     ----------
-    X: array-like, shape (M, N)
+    X: array-like, shape (M, N) or (M, )
         Argument to the logistic function
 
-    out: array-like, shape: (M, N), optional:
+    out: array-like, shape: (M, N) or (M, ), optional:
         Preallocated output array.
 
     Returns
     -------
-    out: array, shape (M, N)
+    out: array, shape (M, N) or (M, )
         Log of the logistic function evaluated at every point in x
 
     Notes
@@ -607,7 +600,8 @@ def log_logistic(X, out=None):
     http://fa.bianp.net/blog/2013/numerical-optimizers-for-logistic-regression/
     """
     is_1d = X.ndim == 1
-    X = check_array(X, dtype=np.float)
+    X = np.atleast_2d(X)
+    X = check_array(X, dtype=np.float64)
 
     n_samples, n_features = X.shape
 
@@ -621,6 +615,40 @@ def log_logistic(X, out=None):
     return out
 
 
+def softmax(X, copy=True):
+    """
+    Calculate the softmax function.
+
+    The softmax function is calculated by
+    np.exp(X) / np.sum(np.exp(X), axis=1)
+
+    This will cause overflow when large values are exponentiated.
+    Hence the largest value in each row is subtracted from each data
+    point to prevent this.
+
+    Parameters
+    ----------
+    X: array-like, shape (M, N)
+        Argument to the logistic function
+
+    copy: bool, optional
+        Copy X or not.
+
+    Returns
+    -------
+    out: array, shape (M, N)
+        Softmax function evaluated at every point in x
+    """
+    if copy:
+        X = np.copy(X)
+    max_prob = np.max(X, axis=1).reshape((-1, 1))
+    X -= max_prob
+    np.exp(X, X)
+    sum_prob = np.sum(X, axis=1).reshape((-1, 1))
+    X /= sum_prob
+    return X
+
+
 def safe_min(X):
     """Returns the minimum value of a dense or a CSR/CSC matrix.
 
@@ -649,8 +677,15 @@ def make_nonnegative(X, min_value=0):
     return X
 
 
-def _batch_mean_variance_update(X, old_mean, old_variance, old_sample_count):
-    """Calculate an average mean update and a Youngs and Cramer variance update.
+def _incremental_mean_and_var(X, last_mean=.0, last_variance=None,
+                              last_sample_count=0):
+    """Calculate mean update and a Youngs and Cramer variance update.
+
+    last_mean and last_variance are statistics computed at the last step by the
+    function. Both must be initialized to 0.0. In case no scaling is required
+    last_variance can be None. The mean is always required and returned because
+    necessary for the calculation of the variance. last_n_samples_seen is the
+    number of samples encountered until now.
 
     From the paper "Algorithms for computing the sample variance: analysis and
     recommendations", by Chan, Golub, and LeVeque.
@@ -660,43 +695,64 @@ def _batch_mean_variance_update(X, old_mean, old_variance, old_sample_count):
     X : array-like, shape (n_samples, n_features)
         Data to use for variance update
 
-    old_mean : array-like, shape: (n_features,)
+    last_mean : array-like, shape: (n_features,)
 
-    old_variance : array-like, shape: (n_features,)
+    last_variance : array-like, shape: (n_features,)
 
-    old_sample_count : int
+    last_sample_count : int
 
     Returns
     -------
     updated_mean : array, shape (n_features,)
 
     updated_variance : array, shape (n_features,)
+        If None, only mean is computed
 
     updated_sample_count : int
 
     References
     ----------
-    T. Chan, G. Golub, R. LeVeque. Algorithms for computing the sample variance:
-        recommendations, The American Statistician, Vol. 37, No. 3, pp. 242-247
+    T. Chan, G. Golub, R. LeVeque. Algorithms for computing the sample
+        variance: recommendations, The American Statistician, Vol. 37, No. 3,
+        pp. 242-247
 
+    Also, see the sparse implementation of this in
+    `utils.sparsefuncs.incr_mean_variance_axis` and
+    `utils.sparsefuncs_fast.incr_mean_variance_axis0`
     """
+    # old = stats until now
+    # new = the current increment
+    # updated = the aggregated stats
+    last_sum = last_mean * last_sample_count
     new_sum = X.sum(axis=0)
-    new_variance = X.var(axis=0) * X.shape[0]
-    old_sum = old_mean * old_sample_count
-    n_samples = X.shape[0]
-    updated_sample_count = old_sample_count + n_samples
-    partial_variance = old_sample_count / (n_samples * updated_sample_count) * (
-        n_samples / old_sample_count * old_sum - new_sum) ** 2
-    unnormalized_variance = old_variance * old_sample_count + new_variance + \
-        partial_variance
-    return ((old_sum + new_sum) / updated_sample_count,
-            unnormalized_variance / updated_sample_count,
-            updated_sample_count)
+
+    new_sample_count = X.shape[0]
+    updated_sample_count = last_sample_count + new_sample_count
+
+    updated_mean = (last_sum + new_sum) / updated_sample_count
+
+    if last_variance is None:
+        updated_variance = None
+    else:
+        new_unnormalized_variance = X.var(axis=0) * new_sample_count
+        if last_sample_count == 0:  # Avoid division by 0
+            updated_unnormalized_variance = new_unnormalized_variance
+        else:
+            last_over_new_count = last_sample_count / new_sample_count
+            last_unnormalized_variance = last_variance * last_sample_count
+            updated_unnormalized_variance = (
+                last_unnormalized_variance +
+                new_unnormalized_variance +
+                last_over_new_count / updated_sample_count *
+                (last_sum / last_over_new_count - new_sum) ** 2)
+        updated_variance = updated_unnormalized_variance / updated_sample_count
+
+    return updated_mean, updated_variance, updated_sample_count
 
 
 def _deterministic_vector_sign_flip(u):
     """Modify the sign of vectors for reproducibility
-    
+
     Flips the sign of elements of all the vectors (rows of u) such that
     the absolute maximum element of each vector is positive.
 
