@@ -1,8 +1,9 @@
 # Author: Olivier Grisel <olivier.grisel@ensta.org>
 #
-# License: BSD Style.
+# License: BSD 3 clause
 
 import numpy as np
+from sklearn.externals.six import b, u
 from sklearn.utils.murmurhash import murmurhash3_32
 from numpy.testing import assert_array_almost_equal
 from numpy.testing import assert_array_equal
@@ -18,9 +19,9 @@ def test_mmhash3_int():
     assert_equal(murmurhash3_32(3, seed=0, positive=False), 847579505)
     assert_equal(murmurhash3_32(3, seed=42, positive=False), -1823081949)
 
-    assert_equal(murmurhash3_32(3, positive=True), 847579505L)
-    assert_equal(murmurhash3_32(3, seed=0, positive=True), 847579505L)
-    assert_equal(murmurhash3_32(3, seed=42, positive=True), 2471885347L)
+    assert_equal(murmurhash3_32(3, positive=True), 847579505)
+    assert_equal(murmurhash3_32(3, seed=0, positive=True), 847579505)
+    assert_equal(murmurhash3_32(3, seed=42, positive=True), 2471885347)
 
 
 def test_mmhash3_int_array():
@@ -43,19 +44,19 @@ def test_mmhash3_int_array():
 
 
 def test_mmhash3_bytes():
-    assert_equal(murmurhash3_32('foo', 0), -156908512)
-    assert_equal(murmurhash3_32('foo', 42), -1322301282)
+    assert_equal(murmurhash3_32(b('foo'), 0), -156908512)
+    assert_equal(murmurhash3_32(b('foo'), 42), -1322301282)
 
-    assert_equal(murmurhash3_32('foo', 0, positive=True), 4138058784L)
-    assert_equal(murmurhash3_32('foo', 42, positive=True), 2972666014L)
+    assert_equal(murmurhash3_32(b('foo'), 0, positive=True), 4138058784)
+    assert_equal(murmurhash3_32(b('foo'), 42, positive=True), 2972666014)
 
 
 def test_mmhash3_unicode():
-    assert_equal(murmurhash3_32(u'foo', 0), -156908512)
-    assert_equal(murmurhash3_32(u'foo', 42), -1322301282)
+    assert_equal(murmurhash3_32(u('foo'), 0), -156908512)
+    assert_equal(murmurhash3_32(u('foo'), 42), -1322301282)
 
-    assert_equal(murmurhash3_32(u'foo', 0, positive=True), 4138058784L)
-    assert_equal(murmurhash3_32(u'foo', 42, positive=True), 2972666014L)
+    assert_equal(murmurhash3_32(u('foo'), 0, positive=True), 4138058784)
+    assert_equal(murmurhash3_32(u('foo'), 42, positive=True), 2972666014)
 
 
 def test_no_collision_on_byte_range():
